(window.textWebpackJsonp=window.textWebpackJsonp||[]).push([[194],{103:function(t,n,e){"use strict";e.r(n);var r=e(886),o=e(205);for(var i in o)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return o[t]}))}(i);e(887),e(888);var s=e(12),a=Object(s.a)(o.default,r.a,r.b,!1,null,"84a83934",null);n.default=a.exports},150:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.getRandomGuestName=n.endpointUrl=n.documentReady=void 0;var r=e(22);
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */n.documentReady=function(t){(document.attachEvent?"complete"===document.readyState:"loading"!==document.readyState)?setTimeout(t,0):document.addEventListener("DOMContentLoaded",t)};const o=(0,r.generateUrl)("/apps/text");n.endpointUrl=(t,n=!1)=>n?"".concat(o,"/public/").concat(t):"".concat(o,"/").concat(t);const i=["Artichoke","Arugula","Asparagus","Avocado","Bamboo Shoot","Bean Sprout","Bean","Beet","Belgian Endive","Bell Pepper","Bitter Melon","Bitter Gourd","Bok Choy","Broccoli","Brussels Sprout","Burdock Root","Cabbage","Calabash","Caper","Carrot","Cassava","Cauliflower","Celery","Celery Root","Celtuce","Chayote","Chinese Broccoli","Corn","Baby Corn","Cucumber","English Cucumber","Gherkin","Pickling Cucumber","Daikon Radish","Edamame","Eggplant","Elephant Garlic","Endive","Curly","Escarole","Fennel","Fiddlehead","Galangal","Garlic","Ginger","Grape Leave","Green Bean","Wax Bean","Green","Amaranth Leave","Beet Green","Collard Green","Dandelion Green","Kale","Kohlrabi Green","Mustard Green","Rapini","Spinach","Swiss Chard","Turnip Green","Hearts of Palm","Horseradish","Jerusalem Artichoke","Jícama","Kale","Curly","Lacinato","Ornamental","Kohlrabi","Leeks","Lemongrass","Lettuce","Butterhead","Iceberg","Leaf","Romaine","Lotus Root","Lotus Seed","Mushroom","Napa Cabbage","Nopales","Okra","Olive","Onion","Green Onion","Parsley","Parsley Root","Parsnip","Pepper","Plantain","Potato","Pumpkin","Purslane","Radicchio","Radish","Rutabaga","Shallots","Spinach","Squash","Sweet Potato","Swiss Chard","Taro","Tomatillo","Tomato","Turnip","Water Chestnut","Water Spinach","Watercress","Winter Melon","Yams","Zucchini"];n.getRandomGuestName=()=>i[Math.floor(Math.random()*i.length)]},159:function(t,n,e){"use strict";e.r(n);var r=e(885),o=e(203);for(var i in o)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return o[t]}))}(i);e(889);var s=e(12),a=Object(s.a)(o.default,r.a,r.b,!1,null,"3ea77884",null);n.default=a.exports},203:function(t,n,e){"use strict";e.r(n);var r=e(204),o=e.n(r);for(var i in r)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return r[t]}))}(i);n.default=o.a},204:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=i(e(8)),o=i(e(103));function i(t){return t&&t.__esModule?t:{default:t}}const s=r.default.observable({messages:[],mtime:0}),a=(t,n)=>{console.debug("callMobileMessage "+t,n);let e=t;void 0!==n&&(e={MessageName:t,Values:n});let r=null;try{r=JSON.stringify(n)}catch(t){r=null}window.DirectEditingMobileInterface&&"function"==typeof window.DirectEditingMobileInterface[t]&&(null==r?window.DirectEditingMobileInterface[t]():window.DirectEditingMobileInterface[t](r)),window.webkit&&window.webkit.messageHandlers&&window.webkit.messageHandlers.DirectEditingMobileInterface&&window.webkit.messageHandlers.DirectEditingMobileInterface.postMessage(e),window.postMessage(e)};window.addEventListener("message",(function(t){s.messages.push(t.data),console.debug("postMessage",t)}));var c={name:"DirectEditing",components:{EditorWrapper:o.default},data:()=>({initial:OCP.InitialState.loadState("text","file"),messages:s.messages,log:s,saving:!1}),computed:{initialSession(){return JSON.parse(this.initial.session)||null}},beforeMount(){a("loading")},mounted(){document.querySelector('meta[name="viewport"]').setAttribute("content","width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0")},methods:{async close(){this.saving=!0,setTimeout(async()=>{await this.$refs.editor.close(),a("close")},0)},share(){a("share")},loaded(){a("loaded")}}};n.default=c},205:function(t,n,e){"use strict";e.r(n);var r=e(206),o=e.n(r);for(var i in r)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return r[t]}))}(i);n.default=o.a},206:function(n,e,r){"use strict";Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0;var o=v(r(8)),i=v(r(207)),s=v(r(631)),a=r(392),c=r(150),l=r(637),d=r(209),u=r(164),p=r(171),h=r(720),A=v(r(724)),f=v(r(405)),C=v(r(178)),m=r(186),g=r(165);function v(t){return t&&t.__esModule?t:{default:t}}var b={name:"EditorWrapper",components:{EditorContent:u.EditorContent,MenuBar:()=>Promise.all([r.e(0),r.e(203),r.e(197)]).then(r.bind(null,830)),MenuBubble:()=>Promise.all([r.e(0),r.e(203),r.e(197)]).then(r.bind(null,837)),ReadOnlyEditor:()=>Promise.all([r.e(193),r.e(202),r.e(194)]).then(r.bind(null,839)),CollisionResolveDialog:()=>Promise.all([r.e(193),r.e(202),r.e(194)]).then(r.bind(null,842)),GuestNameDialog:()=>Promise.all([r.e(0),r.e(192),r.e(196)]).then(r.bind(null,844)),SessionList:()=>Promise.all([r.e(0),r.e(192),r.e(195)]).then(r.bind(null,882))},directives:{Tooltip:C.default},mixins:[A.default,f.default],props:{initialSession:{type:Object,default:null},relativePath:{type:String,default:null},fileId:{type:Number,default:null},active:{type:Boolean,default:!1},autofocus:{type:Boolean,default:!0},shareToken:{type:String,default:null},mime:{type:String,default:null},autohide:{type:Boolean,default:!1},isDirectEditing:{type:Boolean,default:!1}},data:()=>({IDLE_TIMEOUT:a.IDLE_TIMEOUT,tiptap:null,syncService:null,document:null,sessions:[],currentSession:null,filteredSessions:{},idle:!1,dirty:!1,initialLoading:!1,lastSavedString:"",syncError:null,hasConnectionIssue:!1,readOnly:!0,forceRecreate:!1,saveStatusPolling:null}),computed:{showAuthorAnnotations(){return this.$store.state.showAuthorAnnotations},lastSavedStatus(){return this.dirtyStateIndicator?t("text","Saving …"):t("text","Saved")},lastSavedStatusClass(){return this.syncError&&""!==this.lastSavedString?"error":""},dirtyStateIndicator(){return this.hasUnpushedChanges||this.hasUnsavedChanges},lastSavedStatusTooltip(){let n=t("text","Last saved {lastSaved}",{lastSaved:this.lastSavedString});return this.hasSyncCollission&&(n=t("text","The document has been changed outside of the editor. The changes cannot be applied.")),(this.hasUnpushedChanges||this.hasUnsavedChanges)&&(n+=" - "+t("text","Unsaved changes")),{content:n,placement:"bottom"}},hasSyncCollission(){return this.syncError&&this.syncError.type===a.ERROR_TYPE.SAVE_COLLISSION},hasUnpushedChanges(){return this.dirty},hasUnsavedChanges(){return this.document&&this.document.lastSavedVersion<this.document.currentVersion},backendUrl(){return t=>(0,c.endpointUrl)(t,!!this.shareToken)},hasDocumentParameters(){return this.fileId||this.shareToken||this.initialSession},isPublic(){return this.isDirectEditing||document.getElementById("isPublic")&&"1"===document.getElementById("isPublic").value},isRichEditor(){return"text/markdown"===this.mime},fileExtension(){return this.relativePath?this.relativePath.split("/").pop().split(".").pop():"txt"}},watch:{lastSavedStatus(){this.$refs.menubar&&this.$refs.menubar.redrawMenuBar()}},mounted(){this.active&&this.hasDocumentParameters&&this.initSession(),this.$parent.$emit("update:loaded",!0)},created(){this.saveStatusPolling=setInterval(()=>{this.updateLastSavedStatus()},2e3)},beforeDestroy(){this.close()},methods:{async close(){if(clearInterval(this.saveStatusPolling),this.currentSession&&this.syncService)try{await this.syncService.close(),this.currentSession=null,this.syncService=null}catch(t){}return!0},updateLastSavedStatus(){this.document&&(this.lastSavedString=(0,s.default)(1e3*this.document.lastSavedVersionTime).fromNow())},initSession(){if(!this.hasDocumentParameters)return void this.$parent.$emit("error","No valid file provided");const t=localStorage.getItem("nick")?localStorage.getItem("nick"):(0,c.getRandomGuestName)();this.syncService=new a.SyncService({shareToken:this.shareToken,filePath:this.relativePath,guestName:t,forceRecreate:this.forceRecreate,serialize:t=>this.isRichEditor?(0,d.createMarkdownSerializer)(this.tiptap.nodes,this.tiptap.marks).serialize(t):(0,d.serializePlainText)(this.tiptap)}).on("opened",({document:t,session:n})=>{this.currentSession=n,this.document=t,this.readOnly=t.readOnly,localStorage.setItem("nick",this.currentSession.guestName)}).on("change",({document:t,sessions:n})=>{""===this.document.baseVersionEtag||t.baseVersionEtag===this.document.baseVersionEtag?(this.updateSessions.bind(this)(n),this.document=t,this.syncError=null,this.tiptap.setOptions({editable:!this.readOnly})):this.resolveUseServerVersion()}).on("loaded",({documentSource:t})=>{this.hasConnectionIssue=!1,(0,d.loadSyntaxHighlight)(l.extensionHighlight[this.fileExtension]?l.extensionHighlight[this.fileExtension]:this.fileExtension).then(n=>{this.tiptap=(0,d.createEditor)({content:this.isRichEditor?d.markdownit.render(t):"<pre>"+(0,i.default)(t)+"</pre>",onInit:({state:t})=>{this.syncService.state=t,this.syncService.startSync()},onUpdate:({state:t})=>{this.syncService.state=t},extensions:[new p.Collaboration({version:this.document.initialVersion,clientID:this.currentSession.id,debounce:200,onSendable:({sendable:t})=>{this.syncService&&this.syncService.sendSteps()},update:({steps:t,version:n,editor:e})=>{const{state:r,view:o,schema:i}=e;if((0,m.getVersion)(r)>n)return;const s=(0,m.receiveTransaction)(r,t.map(t=>g.Step.fromJSON(i,t.step)),t.map(t=>t.clientID));s.setMeta("clientID",t.map(t=>t.clientID)),o.dispatch(s)}}),new h.UserColor({clientID:this.currentSession.id,color:t=>{const n=this.sessions.find(n=>""+n.id==""+t);return null==n?void 0:n.color},name:t=>{const n=this.sessions.find(n=>""+n.id==""+t);return null!=n&&n.userId?n.userId:null==n?void 0:n.guestName}}),new h.Keymap({"Mod-s":()=>(this.syncService.save(),!0)})],enableRichEditing:this.isRichEditor,languages:n}),this.tiptap.on("focus",()=>{this.$emit("focus")}),this.tiptap.on("blur",()=>{this.$emit("blur")}),this.syncService.state=this.tiptap.state})}).on("sync",({steps:t,document:n})=>{this.hasConnectionIssue=!1;try{this.tiptap.extensions.options.collaboration.update({version:n.currentVersion,steps:t,editor:this.tiptap}),this.syncService.state=this.tiptap.state,this.updateLastSavedStatus()}catch(t){console.error("Failed to update steps in collaboration plugin",t)}this.document=n}).on("error",(t,n)=>{this.tiptap.setOptions({editable:!1}),t!==a.ERROR_TYPE.SAVE_COLLISSION||this.syncError&&this.syncError.type===a.ERROR_TYPE.SAVE_COLLISSION||(this.initialLoading=!0,this.syncError={type:t,data:n}),t!==a.ERROR_TYPE.CONNECTION_FAILED||this.hasConnectionIssue||(this.hasConnectionIssue=!0,OC.Notification.showTemporary("Connection failed, reconnecting"),!1!==n.retry&&setTimeout(this.reconnect.bind(this),5e3)),t===a.ERROR_TYPE.SOURCE_NOT_FOUND&&(this.hasConnectionIssue=!0),this.$emit("ready")}).on("stateChange",t=>{t.initialLoading&&!this.initialLoading&&(this.initialLoading=!0,this.autofocus&&this.tiptap.focus("start"),this.$emit("ready"),this.$parent.$emit("ready",!0)),Object.prototype.hasOwnProperty.call(t,"dirty")&&(this.dirty=t.dirty)}).on("idle",()=>{this.syncService.close(),this.idle=!0,this.readOnly=!0,this.tiptap.setOptions({editable:!this.readOnly})}),null===this.initialSession?this.syncService.open({fileId:this.fileId,filePath:this.relativePath}).catch(t=>{this.hasConnectionIssue=!0}):this.syncService.open({initialSession:this.initialSession}).catch(t=>{this.hasConnectionIssue=!0}),this.forceRecreate=!1},resolveUseThisVersion(){this.syncService.forceSave(),this.tiptap.setOptions({editable:!this.readOnly})},resolveUseServerVersion(){this.forceRecreate=!0,this.reconnect()},reconnect(){this.initialLoading=!1,this.hasConnectionIssue=!1,this.syncService?this.syncService.close().then(()=>{this.syncService=null,this.tiptap.destroy(),this.initSession()}).catch(t=>{}):(this.syncService=null,this.tiptap.destroy(),this.initSession()),this.idle=!1},updateSessions(t){this.sessions=t.sort((t,n)=>n.lastContact-t.lastContact);const n=this.sessions.find(t=>t.id===this.currentSession.id);o.default.set(this,"currentSession",n);const e=this.sessions.map(t=>t.userId),r=this.sessions.map(t=>t.guestId),i=Object.keys(this.filteredSessions).filter(t=>!e.includes(t)&&!r.includes(t));for(const t in i)o.default.delete(this.filteredSessions,i[t]);for(const t in this.sessions){const n=this.sessions[t],e=n.displayName?n.userId:n.id;this.filteredSessions[e]?this.filteredSessions[e].lastContact<n.lastContact&&o.default.set(this.filteredSessions[e],"lastContact",n.lastContact):o.default.set(this.filteredSessions,e,n),n.id===this.currentSession.id&&o.default.set(this.filteredSessions[e],"isCurrent",!0)}}}};e.default=b},209:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.loadSyntaxHighlight=n.serializePlainText=n.createMarkdownSerializer=n.createEditor=n.markdownit=n.default=void 0;var r=e(164),o=e(171),i=e(648),s=e(650),a=u(e(395)),c=u(e(715)),l=e(185);e(716);var d=e(718);function u(t){return t&&t.__esModule?t:{default:t}}
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */n.loadSyntaxHighlight=async t=>{const n=[t],r={};for(let t=0;t<n.length;t++)try{const o=await e(719)("./"+n[t]);r[n[t]]=o.default}catch(t){return}if(0!==Object.keys(r).length||r.constructor!==Object)return{languages:r}};const p=({content:t,onInit:n,onUpdate:e,extensions:a,enableRichEditing:c,languages:d})=>{let u=[];return u=c?[new o.Heading,new o.Code,new i.Strong,new i.Italic,new i.Strike,new o.HardBreak,new o.HorizontalRule,new s.BulletList,new o.OrderedList,new o.Blockquote,new o.CodeBlock,new s.ListItem,new i.Link({openOnClick:!0}),new s.Image,new o.Placeholder({emptyNodeClass:"is-empty",emptyNodeText:(0,l.translate)("text","Add notes, lists or links …"),showOnlyWhenEditable:!0})]:[new s.PlainTextDocument,new r.Text,new o.CodeBlockHighlight({...d})],a=a||[],new r.Editor({content:t,onInit:n,onUpdate:e,extensions:[...u,new o.History].concat(a),useBuiltInExtensions:c})};n.createEditor=p;const h=(0,a.default)("commonmark",{html:!1,breaks:!1}).enable("strikethrough").use(c.default,{enable:!0,labelAfter:!0});n.markdownit=h;const A=function(t){this.message=t};n.createMarkdownSerializer=(t,n)=>{const e=Object.entries(t).filter(([,t])=>t.toMarkdown).reduce((t,[n,{toMarkdown:e}])=>({...t,[n]:e}),{}),r=Object.entries(n).filter(([,t])=>t.toMarkdown).reduce((t,[n,{toMarkdown:e}])=>({...t,[n]:e}),{});return{serializer:new d.MarkdownSerializer({...d.defaultMarkdownSerializer.nodes,...e},{...d.defaultMarkdownSerializer.marks,...r}),serialize(t,n){return this.serializer.serialize(t,{...n,tightLists:!0}).split("\\[").join("[").split("\\]").join("]")}}};n.serializePlainText=t=>{const n=t.getJSON();if(1!==n.content.length||void 0===n.content[0].content||1!==n.content[0].content.length){if("code_block"===n.content[0].type&&void 0===n.content[0].content)return"";throw new A("Failed to serialize document to plain text")}const e=n.content[0].content[0];if("text"!==e.type)throw new A("Failed to serialize document to plain text");return e.text};var f=p;n.default=f},212:function(t,n,e){"use strict";e.r(n);var r=e(213),o=e.n(r);for(var i in r)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return r[t]}))}(i);n.default=o.a},213:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,o=(r=e(653))&&r.__esModule?r:{default:r},i=e(22);const s=["image/png","image/jpeg","image/gif","image/x-xbitmap","image/bmp","image/svg+xml"],a=(t,n)=>{const e=t.split("?")[1];if(void 0===e)return;const r=e.split(/[&#]/);if(void 0!==r)for(let t=0;t<r.length;t++){const e=r[t].split("=");if(decodeURIComponent(e[0])===n)return decodeURIComponent(e[1])}};var c={name:"ImageView",props:["node","updateAttrs","view"],data:()=>({imageLoaded:!1,loaded:!1,failed:!1}),computed:{imageUrl(){if(this.src.startsWith("http://")||this.src.startsWith("https://"))return this.src;if(this.hasPreviewUrl)return this.src;if(this.fileId)return(0,i.generateUrl)("/core/preview")+"?fileId=".concat(this.fileId,"&x=1024&y=1024&a=true");const t=FileList.getCurrentDirectory()+"/"+this.src,n=encodeURIComponent(o.default.normalize(t));return(0,i.generateUrl)("/core/preview.png")+"?file=".concat(n,"&x=1024&y=1024&a=true")},fileId(){return a(this.src,"fileId")},hasPreviewUrl(){return this.src.match(/^(\/index.php)?\/core\/preview/)||this.src.match(/^(\/index.php)?\/apps\/files_sharing\/publicpreview\//)},mimeIcon(){const t=a(this.src,"mimetype");return t?{backgroundImage:"url("+window.OC.MimeType.getIconUrl(t)+")"}:{}},isSupportedImage(){const t=a(this.src,"mimetype");return void 0===t||-1!==s.indexOf(t)},internalLinkOrImage(){const t=a(this.src,"fileId");return t?(0,i.generateUrl)("/f/"+t):this.src},src:{get(){return this.node.attrs.src},set(t){this.updateAttrs({src:t})}},alt:{get(){return this.node.attrs.alt?this.node.attrs.alt:""},set(t){this.updateAttrs({alt:t})}},t:()=>(t,n)=>window.t(t,n)},beforeMount(){if(!this.isSupportedImage)return this.failed=!0,this.imageLoaded=!1,void(this.loaded=!0);const t=new Image;t.src=this.imageUrl,t.onload=()=>{this.imageLoaded=!0},t.onerror=()=>{this.failed=!0,this.imageLoaded=!1,this.loaded=!0}},methods:{updateAlt(){this.alt=this.$refs.altInput.value},onLoaded(){this.loaded=!0}}};n.default=c},225:function(t,n,e){"use strict";n.a="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZlcnNpb249IjEuMSIgdmlld2JveD0iMCAwIDE2IDE2IiB3aWR0aD0iMTYiIGhlaWdodD0iMTYiPjxwYXRoIGQ9Ik0xMS45MjQgNC4wNjZsLTQuOTMyIDQuOTctMi44MjgtMi44M0wyLjc1IDcuNjE4bDQuMjQyIDQuMjQzIDYuMzY1LTYuMzY1LTEuNDMzLTEuNDMyeiIgZmlsbD0iI2ZmZiIvPjwvc3ZnPgo="},254:function(t,n,e){"use strict";e.r(n);var r=e(255),o=e.n(r);for(var i in r)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return r[t]}))}(i);n.default=o.a},255:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,o=e(164),i=(r=e(207))&&r.__esModule?r:{default:r},s=e(209);var a={name:"ReadOnlyEditor",components:{EditorContent:o.EditorContent},props:{content:{type:String,required:!0},isRichEditor:{type:Boolean,default:!0}},data:()=>({editor:null}),mounted(){this.editor=(0,s.createEditor)({content:this.isRichEditor?s.markdownit.render(this.content):"<pre>"+(0,i.default)(this.content)+"</pre>",enableRichEditing:this.isRichEditor}),this.editor.setOptions({editable:!1})},beforeDestroy(){this.editor.destroy()}};n.default=a},256:function(t,n,e){"use strict";e.r(n);var r=e(257),o=e.n(r);for(var i in r)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return r[t]}))}(i);n.default=o.a},257:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;n.default={name:"CollisionResolveDialog"}},38:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=i(e(8)),o=i(e(73));function i(t){return t&&t.__esModule?t:{default:t}}
/*
 * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */const s=(0,e(55).getBuilder)("text").persist().build();r.default.use(o.default);const a=new o.default.Store({state:{showAuthorAnnotations:"true"===s.getItem("showAuthorAnnotations")},mutations:{SET_SHOW_AUTHOR_ANNOTATIONS(t,n){t.showAuthorAnnotations=n,s.setItem("showAuthorAnnotations",""+n)}},actions:{setShowAuthorAnnotations({commit:t},n){a.commit("SET_SHOW_AUTHOR_ANNOTATIONS",n)}}});var c=a;n.default=c},392:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.IDLE_TIMEOUT=n.ERROR_TYPE=n.SyncService=n.default=void 0;var r=a(e(75)),o=a(e(635)),i=e(150),s=e(186);function a(t){return t&&t.__esModule?t:{default:t}}function c(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}const l={shareToken:null,forceRecreate:!1,serialize:t=>t};n.IDLE_TIMEOUT=30;const d={SAVE_COLLISSION:0,PUSH_FAILURE:1,LOAD_ERROR:2,CONNECTION_FAILED:3,SOURCE_NOT_FOUND:4};n.ERROR_TYPE=d;let u=function(){function t(n){return function(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}(this,t),this.eventHandlers={opened:[],loaded:[],fetched:[],sync:[],stateChange:[],error:[],change:[],save:[],idle:[]},this.backend=new o.default(this),this.options=Object.assign({},l,n),this.document=null,this.session=null,this.sessions=[],this.steps=[],this.stepClientIDs=[],this.lastStepPush=Date.now(),this}var n,e,a;return n=t,(e=[{key:"open",value:async function({fileId:t,filePath:n,initialSession:e}){let r=null;if(void 0===e)try{r=(await this._openDocument({fileId:t,filePath:n})).data}catch(t){throw t.response&&"ECONNABORTED"!==t.code?this.emit("error",d.LOAD_ERROR,t.response.status):this.emit("error",d.CONNECTION_FAILED,{}),t}else r=e;return this.document=r.document,this.document.readOnly=r.readOnly,this.session=r.session,this.emit("opened",{document:this.document,session:this.session}),this._fetchDocument().then(({data:t})=>{this.emit("loaded",{document:this.document,session:this.session,documentSource:""+t})})}},{key:"startSync",value:function(){this.backend.connect()}},{key:"_openDocument",value:function({fileId:t,filePath:n}){return r.default.put((0,i.endpointUrl)("session/create",!!this.options.shareToken),{fileId:t,filePath:n,token:this.options.shareToken,guestName:this.options.guestName,forceRecreate:this.options.forceRecreate})}},{key:"_fetchDocument",value:function(){return r.default.post((0,i.endpointUrl)("session/fetch",!!this.options.shareToken),{documentId:this.document.id,sessionId:this.session.id,sessionToken:this.session.token,token:this.options.shareToken},{transformResponse:[t=>t]})}},{key:"updateSession",value:function(t){if(this.isPublic())return r.default.post((0,i.endpointUrl)("session",!!this.options.shareToken),{documentId:this.document.id,sessionId:this.session.id,sessionToken:this.session.token,token:this.options.shareToken,guestName:t}).then(({data:t})=>(this.session=t,t)).catch(t=>(console.error("Failed to update the session",t),Promise.reject(t)))}},{key:"sendSteps",value:function(t){const n=t||(0,s.sendableSteps)(this.state);if(n)return this.backend.sendSteps(n)}},{key:"stepsSince",value:function(t){return{steps:this.steps.slice(t),clientIDs:this.stepClientIDs.slice(t)}}},{key:"_receiveSteps",value:function({steps:t,document:n}){const e=[];for(let n=0;n<t.length;n++){const r=t[n].data;Array.isArray(r)?r.forEach(r=>{this.steps.push(r),e.push({step:r,clientID:t[n].sessionId})}):console.error("Invalid step data, skipping step",t[n])}this.lastStepPush=Date.now(),this.emit("sync",{steps:e,document:n}),console.debug("receivedSteps","newVersion",this._getVersion())}},{key:"checkIdle",value:function(){(Date.now()-this.lastStepPush)/1e3/60>30&&(console.debug("[SyncService] Document is idle for ".concat(this.IDLE_TIMEOUT," minutes, suspending connection")),this.emit("idle"))}},{key:"_getVersion",value:function(){return this.state?(0,s.getVersion)(this.state):0}},{key:"_getDocument",value:function(){if(this.state)return this.state.doc}},{key:"_getContent",value:function(){return this.options.serialize(this._getDocument())}},{key:"save",value:function(){this.backend.save&&this.backend.save()}},{key:"forceSave",value:function(){this.backend.forceSave&&this.backend.forceSave()}},{key:"close",value:function(){let t=!1;return new Promise((n,e)=>{this.on("save",()=>{this._close().then(()=>{t=!0,n()}).catch(()=>n())}),setTimeout(()=>{t||this._close().then(()=>{n()}).catch(()=>n())},2e3),this.save()})}},{key:"_close",value:function(){return null===this.document||null===this.session?Promise.resolve():(this.backend.disconnect(),r.default.post((0,i.endpointUrl)("session/close",!!this.options.shareToken),{documentId:this.document.id,sessionId:this.session.id,sessionToken:this.session.token,token:this.options.shareToken}))}},{key:"on",value:function(t,n,e){return this.eventHandlers[t].push(n.bind(e)),this}},{key:"emit",value:function(t,n,e){void 0!==this.eventHandlers[t]?this.eventHandlers[t].forEach((function(t){t(n,e)})):console.error("Event not found",t)}},{key:"isPublic",value:function(){return!!this.options.shareToken}}])&&c(n.prototype,e),a&&c(n,a),t}();n.SyncService=u;var p=u;n.default=p},404:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.Span=void 0;n.Span=function t(n,e,r){!function(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}
/*
 * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */(this,t),this.from=n,this.to=e,this.author=r}},405:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,o=(r=e(38))&&r.__esModule?r:{default:r};
/*
 * @copyright Copyright (c) 2021 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
var i={data:()=>({$store:o.default}),beforeMount(){void 0===this.$store&&(this.$store=o.default)}};n.default=i},632:function(t,n,e){var r={"./af":265,"./af.js":265,"./ar":266,"./ar-dz":267,"./ar-dz.js":267,"./ar-kw":268,"./ar-kw.js":268,"./ar-ly":269,"./ar-ly.js":269,"./ar-ma":270,"./ar-ma.js":270,"./ar-sa":271,"./ar-sa.js":271,"./ar-tn":272,"./ar-tn.js":272,"./ar.js":266,"./az":273,"./az.js":273,"./be":274,"./be.js":274,"./bg":275,"./bg.js":275,"./bm":276,"./bm.js":276,"./bn":277,"./bn.js":277,"./bo":278,"./bo.js":278,"./br":279,"./br.js":279,"./bs":280,"./bs.js":280,"./ca":281,"./ca.js":281,"./cs":282,"./cs.js":282,"./cv":283,"./cv.js":283,"./cy":284,"./cy.js":284,"./da":285,"./da.js":285,"./de":286,"./de-at":287,"./de-at.js":287,"./de-ch":288,"./de-ch.js":288,"./de.js":286,"./dv":289,"./dv.js":289,"./el":290,"./el.js":290,"./en-SG":291,"./en-SG.js":291,"./en-au":292,"./en-au.js":292,"./en-ca":293,"./en-ca.js":293,"./en-gb":294,"./en-gb.js":294,"./en-ie":295,"./en-ie.js":295,"./en-il":296,"./en-il.js":296,"./en-nz":297,"./en-nz.js":297,"./eo":298,"./eo.js":298,"./es":299,"./es-do":300,"./es-do.js":300,"./es-us":301,"./es-us.js":301,"./es.js":299,"./et":302,"./et.js":302,"./eu":303,"./eu.js":303,"./fa":304,"./fa.js":304,"./fi":305,"./fi.js":305,"./fo":306,"./fo.js":306,"./fr":307,"./fr-ca":308,"./fr-ca.js":308,"./fr-ch":309,"./fr-ch.js":309,"./fr.js":307,"./fy":310,"./fy.js":310,"./ga":311,"./ga.js":311,"./gd":312,"./gd.js":312,"./gl":313,"./gl.js":313,"./gom-latn":314,"./gom-latn.js":314,"./gu":315,"./gu.js":315,"./he":316,"./he.js":316,"./hi":317,"./hi.js":317,"./hr":318,"./hr.js":318,"./hu":319,"./hu.js":319,"./hy-am":320,"./hy-am.js":320,"./id":321,"./id.js":321,"./is":322,"./is.js":322,"./it":323,"./it-ch":324,"./it-ch.js":324,"./it.js":323,"./ja":325,"./ja.js":325,"./jv":326,"./jv.js":326,"./ka":327,"./ka.js":327,"./kk":328,"./kk.js":328,"./km":329,"./km.js":329,"./kn":330,"./kn.js":330,"./ko":331,"./ko.js":331,"./ku":332,"./ku.js":332,"./ky":333,"./ky.js":333,"./lb":334,"./lb.js":334,"./lo":335,"./lo.js":335,"./lt":336,"./lt.js":336,"./lv":337,"./lv.js":337,"./me":338,"./me.js":338,"./mi":339,"./mi.js":339,"./mk":340,"./mk.js":340,"./ml":341,"./ml.js":341,"./mn":342,"./mn.js":342,"./mr":343,"./mr.js":343,"./ms":344,"./ms-my":345,"./ms-my.js":345,"./ms.js":344,"./mt":346,"./mt.js":346,"./my":347,"./my.js":347,"./nb":348,"./nb.js":348,"./ne":349,"./ne.js":349,"./nl":350,"./nl-be":351,"./nl-be.js":351,"./nl.js":350,"./nn":352,"./nn.js":352,"./pa-in":353,"./pa-in.js":353,"./pl":354,"./pl.js":354,"./pt":355,"./pt-br":356,"./pt-br.js":356,"./pt.js":355,"./ro":357,"./ro.js":357,"./ru":358,"./ru.js":358,"./sd":359,"./sd.js":359,"./se":360,"./se.js":360,"./si":361,"./si.js":361,"./sk":362,"./sk.js":362,"./sl":363,"./sl.js":363,"./sq":364,"./sq.js":364,"./sr":365,"./sr-cyrl":366,"./sr-cyrl.js":366,"./sr.js":365,"./ss":367,"./ss.js":367,"./sv":368,"./sv.js":368,"./sw":369,"./sw.js":369,"./ta":370,"./ta.js":370,"./te":371,"./te.js":371,"./tet":372,"./tet.js":372,"./tg":373,"./tg.js":373,"./th":374,"./th.js":374,"./tl-ph":375,"./tl-ph.js":375,"./tlh":376,"./tlh.js":376,"./tr":377,"./tr.js":377,"./tzl":378,"./tzl.js":378,"./tzm":379,"./tzm-latn":380,"./tzm-latn.js":380,"./tzm.js":379,"./ug-cn":381,"./ug-cn.js":381,"./uk":382,"./uk.js":382,"./ur":383,"./ur.js":383,"./uz":384,"./uz-latn":385,"./uz-latn.js":385,"./uz.js":384,"./vi":386,"./vi.js":386,"./x-pseudo":387,"./x-pseudo.js":387,"./yo":388,"./yo.js":388,"./zh-cn":389,"./zh-cn.js":389,"./zh-hk":390,"./zh-hk.js":390,"./zh-tw":391,"./zh-tw.js":391};function o(t){var n=i(t);return e(n)}function i(t){if(!e.o(r,t)){var n=new Error("Cannot find module '"+t+"'");throw n.code="MODULE_NOT_FOUND",n}return r[t]}o.keys=function(){return Object.keys(r)},o.resolve=i,t.exports=o,o.id=632},635:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,o=(r=e(75))&&r.__esModule?r:{default:r},i=e(150),s=e(392),a=e(186);function c(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}var l=function(){function t(n){!function(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}(this,t),this._authority=n,this.fetchInterval=300,this.retryTime=500,this.lock=!1,this.fetchRetryCounter=0}var n,e,r;return n=t,(e=[{key:"connect",value:function(){this.initialLoadingFinished=!1,this.fetcher=setInterval(this._fetchSteps.bind(this),50),document.addEventListener("visibilitychange",this.visibilitychange.bind(this))}},{key:"_isPublic",value:function(){return!!this._authority.options.shareToken}},{key:"forceSave",value:function(){this._forcedSave=!0,this.fetchSteps()}},{key:"save",value:function(){this._manualSave=!0,this.fetchSteps()}},{key:"fetchSteps",value:function(){this._fetchSteps()}},{key:"_fetchSteps",value:function(){if(this.lock||!this.fetcher)return;let t;this.lock=!0,(this._forcedSave||this._manualSave||!(0,a.sendableSteps)(this._authority.state)&&this._authority._getVersion()!==this._authority.document.lastSavedVersion)&&(t=this._authority._getContent()),o.default.post((0,i.endpointUrl)("session/sync",this._isPublic()),{documentId:this._authority.document.id,sessionId:this._authority.session.id,sessionToken:this._authority.session.token,version:this._authority._getVersion(),autosaveContent:t,force:!!this._forcedSave,manualSave:!!this._manualSave,token:this._authority.options.shareToken,filePath:this._authority.options.filePath}).then(t=>{if(this.fetchRetryCounter=0,this._authority.document.lastSavedVersion<t.data.document.lastSavedVersion&&(console.debug("Saved document",t.data.document),this._authority.emit("save",{document:t.data.document,sessions:t.data.sessions})),this._authority.emit("change",{document:t.data.document,sessions:t.data.sessions}),this._authority.document=t.data.document,this._authority.sessions=t.data.sessions,0===t.data.steps.length){if(this.initialLoadingFinished||(this.initialLoadingFinished=!0),this._authority.checkIdle())return;return this.lock=!1,t.data.sessions.filter(t=>t.lastContact>Date.now()/1e3-9e4).length<2?this.maximumRefetchTimer():this.increaseRefetchTimer(),this._authority.emit("stateChange",{dirty:!1}),void this._authority.emit("stateChange",{initialLoading:!0})}this._authority._receiveSteps(t.data),this.lock=!1,this._forcedSave=!1,this.initialLoadingFinished&&this.resetRefetchTimer()}).catch(t=>{this.lock=!1,t.response&&"ECONNABORTED"!==t.code?409===t.response.status&&t.response.data.document.currentVersion===this._authority.document.currentVersion?(console.error("Conflict during file save, please resolve"),this._authority.emit("error",s.ERROR_TYPE.SAVE_COLLISSION,{outsideChange:t.response.data.outsideChange})):403===t.response.status||404===t.response.status?(this._authority.emit("error",s.ERROR_TYPE.SOURCE_NOT_FOUND,{}),this.disconnect()):503===t.response.status?(this.increaseRefetchTimer(),this._authority.emit("error",s.ERROR_TYPE.CONNECTION_FAILED,{retry:!1}),console.error("Failed to fetch steps due to unavailable service",t)):(this.disconnect(),this._authority.emit("error",s.ERROR_TYPE.CONNECTION_FAILED,{retry:!1}),console.error("Failed to fetch steps due to other reason",t)):this.fetchRetryCounter++>=5?(console.error("[PollingBackend:fetchSteps] Network error when fetching steps, emitting CONNECTION_FAILED"),this._authority.emit("error",s.ERROR_TYPE.CONNECTION_FAILED,{retry:!1})):console.error("[PollingBackend:fetchSteps] Network error when fetching steps, retry ".concat(this.fetchRetryCounter))}),this._manualSave=!1,this._forcedSave=!1}},{key:"sendSteps",value:function(t){if(this._authority.emit("stateChange",{dirty:!0}),this.lock)return void setTimeout(()=>{this._authority.sendSteps()},100);this.lock=!0;const n="function"==typeof t?t():t,e=n.steps;o.default.post((0,i.endpointUrl)("session/push",!!this._authority.options.shareToken),{documentId:this._authority.document.id,sessionId:this._authority.session.id,sessionToken:this._authority.session.token,steps:e.map(t=>t.toJSON?t.toJSON():t)||[],version:n.version,token:this._authority.options.shareToken,filePath:this._authority.options.filePath}).then(t=>{this.carefulRetryReset(),this.lock=!1,this.fetchSteps()}).catch(t=>{console.error("failed to apply steps due to collission, retrying"),this.lock=!1,t.response&&"ECONNABORTED"!==t.code?(403===t.response.status&&t.response.data.document.currentVersion===this._authority.document.currentVersion&&(this._authority.emit("error",s.ERROR_TYPE.PUSH_FAILURE,{}),OC.Notification.showTemporary("Changes could not be sent yet")),this.fetchSteps(),this.carefulRetry()):this._authority.emit("error",s.ERROR_TYPE.CONNECTION_FAILED,{})})}},{key:"disconnect",value:function(){clearInterval(this.fetcher),this.fetcher=0,document.removeEventListener("visibilitychange",this.visibilitychange.bind(this))}},{key:"resetRefetchTimer",value:function(){0!==this.fetcher&&(this.fetchInterval=300,clearInterval(this.fetcher),this.fetcher=setInterval(this._fetchSteps.bind(this),this.fetchInterval))}},{key:"increaseRefetchTimer",value:function(){0!==this.fetcher&&(this.fetchInterval=Math.min(2*this.fetchInterval,5e3),clearInterval(this.fetcher),this.fetcher=setInterval(this._fetchSteps.bind(this),this.fetchInterval))}},{key:"maximumRefetchTimer",value:function(){0!==this.fetcher&&(this.fetchInterval=5e3,clearInterval(this.fetcher),this.fetcher=setInterval(this._fetchSteps.bind(this),this.fetchInterval))}},{key:"visibilitychange",value:function(){0!==this.fetcher&&("hidden"===document.visibilityState?(this.fetchInterval=6e4,clearInterval(this.fetcher),this.fetcher=setInterval(this._fetchSteps.bind(this),this.fetchInterval)):this.resetRefetchTimer())}},{key:"carefulRetry",value:function(){const t=this.retryTime?Math.min(2*this.retryTime,1e4):500;t>5e3&&this.retryTime<5e3&&(OC.Notification.showTemporary("Changes could not be sent yet"),this._authority.emit("error",s.ERROR_TYPE.PUSH_FAILURE,{})),this.retryTime=t}},{key:"carefulRetryReset",value:function(){this.retryTime=500}}])&&c(n.prototype,e),r&&c(n,r),t}();n.default=l},637:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.extensionHighlight=n.default=void 0;
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
const r={py:"python",gyp:"python",wsgi:"python",htm:"html",xhtml:"html",erl:"erlang",jsp:"java",pl:"perl",rss:"xml",atom:"xml",xsl:"xml",plist:"xml",rb:"ruby",builder:"ruby",gemspec:"ruby",podspec:"ruby",thor:"ruby",diff:"patch",hs:"haskell",icl:"haskell",php3:"php",php4:"php",php5:"php",php6:"php",sh:"bash",zsh:"bash",st:"smalltalk",as:"actionscript",apacheconf:"apache",osacript:"applescript",b:"brainfuck",bf:"brainfuck",clj:"clojure","cmake.in":"cmake",coffee:"coffeescript",cson:"coffescript",iced:"coffescript",c:"cpp",h:"cpp","c++":"cpp","h++":"cpp",hh:"cpp",jinja:"django",bat:"dos",cmd:"dos",fs:"fsharp",hbs:"handlebars","html.hbs":"handlebars","html.handlebars":"handlebars",sublime_metrics:"json",sublime_session:"json","sublime-keymap":"json","sublime-mousemap":"json","sublime-project":"json","sublime-settings":"json","sublime-workspace":"json",mk:"makefile",mak:"makefile",md:"markdown",mkdown:"markdown",mkd:"markdown",nginxconf:"nginx",m:"objectivec",mm:"objectivec",ml:"ocaml",rs:"rust",sci:"scilab",vb:"vbnet",vbs:"vbscript"};n.extensionHighlight=r;var o=r;n.default=o},648:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.Link=n.Strike=n.Italic=n.Strong=void 0;var r=e(171),o=e(164),i=e(187),s=e(649),a=e(209);function c(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}function l(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function d(t,n,e){return n&&l(t.prototype,n),e&&l(t,e),t}function u(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(n&&n.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),n&&p(t,n)}function p(t,n){return(p=Object.setPrototypeOf||function(t,n){return t.__proto__=n,t})(t,n)}function h(t){var n=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var e,r=f(t);if(n){var o=f(this).constructor;e=Reflect.construct(r,arguments,o)}else e=r.apply(this,arguments);return A(this,e)}}function A(t,n){return!n||"object"!=typeof n&&"function"!=typeof n?function(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):n}function f(t){return(f=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}let C=function(t){u(e,t);var n=h(e);function e(){return c(this,e),n.apply(this,arguments)}return d(e,[{key:"name",get:function(){return"strong"}}]),e}(r.Bold);n.Strong=C;let m=function(t){u(e,t);var n=h(e);function e(){return c(this,e),n.apply(this,arguments)}return d(e,[{key:"name",get:function(){return"em"}}]),e}(r.Italic);n.Italic=m;let g=function(t){u(e,t);var n=h(e);function e(){return c(this,e),n.apply(this,arguments)}return d(e,[{key:"schema",get:function(){return{parseDOM:[{tag:"s"},{tag:"del"},{tag:"strike"},{style:"text-decoration",getAttrs:t=>"line-through"===t}],toDOM:()=>["s",0],toMarkdown:{open:"~~",close:"~~",mixable:!0,expelEnclosingWhitespace:!0}}}}]),e}(r.Strike);n.Strike=g;let v=function(t){u(e,t);var n=h(e);function e(){return c(this,e),n.apply(this,arguments)}return d(e,[{key:"schema",get:function(){return{attrs:{href:{default:null}},inclusive:!1,parseDOM:[{tag:"a[href]",getAttrs:t=>({href:(0,s.parseHref)(t)})}],toDOM:t=>["a",{...t.attrs,href:(0,s.domHref)(t),title:t.attrs.href,rel:"noopener noreferrer nofollow"},0]}}},{key:"plugins",get:function(){return this.options.openOnClick?[new o.Plugin({props:{handleClick:(t,n,e)=>{const{schema:r}=t.state,o=(0,i.getMarkAttrs)(t.state,r.marks.link),s=e.target instanceof HTMLAnchorElement||e.target.parentElement instanceof HTMLAnchorElement;if(o.href&&s){const t=e.target.parentElement instanceof HTMLAnchorElement?e.target.parentElement:e.target;e.stopPropagation();const n=t.href;if(0===e.button&&!e.ctrlKey&&n.startsWith(window.location.origin)){const t=OC.parseQueryString(n),e=OC.parseQueryString(n.split("#").pop());if(t.dir&&e.relPath){const n=e.relPath.split("/").pop(),r="".concat(t.dir,"/").concat(n);return document.title="".concat(n," - ").concat(OC.theme.title),window.location.pathname.match(/apps\/files\/$/),void OCA.Viewer.open({path:r})}}if(!a.markdownit.validateLink(n))return void console.error("Invalid link",n);window.open(n)}}}})]:[]}}]),e}(r.Link);n.Link=v},649:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.parseHref=n.domHref=void 0;var r=e(22);
/*
 * @copyright Copyright (c) 2020 Azul <azul@riseup.net>
 *
 * @author Azul <azul@riseup.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */const o=function(t){const n=t.lastIndexOf("/");return n>0?t.slice(0,n):t.slice(0,n+1)};n.domHref=function(t){const n=t.attrs.href;if(!n)return n;if(n.match(/^[a-zA-Z]*:/))return n;const e=n.match(/^([^?]*)\?fileId=(\d+)/);if(e){const[,t,n]=e,i=function(t,n){if(!n)return t;if("/"===n[0])return n;for(t=t.split("/"),n=n.split("/");".."===n[0]||"."===n[0];)".."===n[0]&&t.pop(),n.shift();return t.concat(n).join("/")}(o(OCA.Viewer.file),o(t));return(0,r.generateUrl)("/apps/files/?dir=".concat(i,"&openfile=").concat(n,"#relPath=").concat(t))}};n.parseHref=function(t){const n=t.getAttribute("href");if(!n)return n;const e=n.match(/\?dir=([^&]*)&openfile=([^&]*)#relPath=([^&]*)/);if(e){const[,,t,n]=e;return"".concat(n,"?fileId=").concat(t)}return n}},650:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),Object.defineProperty(n,"Image",{enumerable:!0,get:function(){return r.default}}),Object.defineProperty(n,"PlainTextDocument",{enumerable:!0,get:function(){return o.default}}),Object.defineProperty(n,"ListItem",{enumerable:!0,get:function(){return i.default}}),Object.defineProperty(n,"BulletList",{enumerable:!0,get:function(){return s.default}});var r=a(e(651)),o=a(e(655)),i=a(e(656)),s=a(e(660));function a(t){return t&&t.__esModule?t:{default:t}}},651:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,o=e(171),i=(r=e(652))&&r.__esModule?r:{default:r};function s(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}function a(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function c(t,n,e){return(c="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(t,n,e){var r=function(t,n){for(;!Object.prototype.hasOwnProperty.call(t,n)&&null!==(t=p(t)););return t}(t,n);if(r){var o=Object.getOwnPropertyDescriptor(r,n);return o.get?o.get.call(e):o.value}})(t,n,e||t)}function l(t,n){return(l=Object.setPrototypeOf||function(t,n){return t.__proto__=n,t})(t,n)}function d(t){var n=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var e,r=p(t);if(n){var o=p(this).constructor;e=Reflect.construct(r,arguments,o)}else e=r.apply(this,arguments);return u(this,e)}}function u(t,n){return!n||"object"!=typeof n&&"function"!=typeof n?function(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):n}function p(t){return(p=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}let h=function(t){!function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(n&&n.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),n&&l(t,n)}(u,t);var n,e,r,o=d(u);function u(){return s(this,u),o.apply(this,arguments)}return n=u,(e=[{key:"view",get:function(){return i.default}},{key:"schema",get:function(){return{...c(p(u.prototype),"schema",this),selectable:!1}}}])&&a(n.prototype,e),r&&a(n,r),u}(o.Image);n.default=h},652:function(t,n,e){"use strict";e.r(n);var r=e(904),o=e(212);for(var i in o)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return o[t]}))}(i);e(905);var s=e(12),a=Object(s.a)(o.default,r.a,r.b,!1,null,"efec1cb6",null);n.default=a.exports},654:function(t,n,e){"use strict";var r=e(20),o=e.n(r),i=e(21),s=e.n(i)()(o.a);s.push([t.i,".image[data-v-efec1cb6]{margin:0;padding:0}.image__caption[data-v-efec1cb6]{text-align:center;color:var(--color-text-lighter)}.image__caption input[type='text'][data-v-efec1cb6]{width:100%;border:none;text-align:center}.icon-image[data-v-efec1cb6]{margin-top:10px;height:32px;padding:20px;background-size:contain}.image__loading[data-v-efec1cb6]{height:100px}.image__view[data-v-efec1cb6]{text-align:center}.image__view .image__main[data-v-efec1cb6]{max-height:40vh}.image__placeholder a[data-v-efec1cb6]{display:flex}.image__placeholder .image__main[data-v-efec1cb6]{background-color:var(--color-background-dark);text-align:center;padding:5px;border-radius:var(--border-radius)}.image__placeholder .image__main .icon-image[data-v-efec1cb6]{margin:0}.image__placeholder .image__main p[data-v-efec1cb6]{padding:10px}.fade-enter-active[data-v-efec1cb6]{transition:opacity .3s ease-in-out}.fade-enter-to[data-v-efec1cb6]{opacity:1}.fade-enter[data-v-efec1cb6]{opacity:0}\n","",{version:3,sources:["webpack://./src/nodes/ImageView.vue"],names:[],mappings:"AAoMA,wBACC,QAAS,CACT,SAAU,CACV,iCAGA,iBAAkB,CAClB,+BAAgC,CAFjC,oDAIE,UAAW,CACX,WAAY,CACZ,iBAAkB,CAClB,6BAID,eAAgB,CAChB,WAAY,CACZ,YAAa,CACb,uBAAwB,CACxB,iCAGA,YAAa,CACb,8BAGA,iBAAkB,CADnB,2CAIE,eAAgB,CAChB,uCAKA,YAAa,CAFf,kDAKE,6CAA8C,CAC9C,iBAAkB,CAClB,WAAY,CACZ,kCAAmC,CARrC,8DAWG,QAAS,CAXZ,oDAeG,YAAa,CACb,oCAKF,kCAAmC,CACnC,gCAGA,SAAU,CACV,6BAGA,SAAU",sourcesContent:["\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n.image {\n\tmargin: 0;\n\tpadding: 0;\n}\n\n.image__caption {\n\ttext-align: center;\n\tcolor: var(--color-text-lighter);\n\tinput[type='text'] {\n\t\twidth: 100%;\n\t\tborder: none;\n\t\ttext-align: center;\n\t}\n}\n\n.icon-image {\n\tmargin-top: 10px;\n\theight: 32px;\n\tpadding: 20px;\n\tbackground-size: contain;\n}\n\n.image__loading {\n\theight: 100px;\n}\n\n.image__view {\n\ttext-align: center;\n\n\t.image__main {\n\t\tmax-height: 40vh;\n\t}\n}\n\n.image__placeholder {\n\ta {\n\t\tdisplay: flex;\n\t}\n\t.image__main {\n\t\tbackground-color: var(--color-background-dark);\n\t\ttext-align: center;\n\t\tpadding: 5px;\n\t\tborder-radius: var(--border-radius);\n\n\t\t.icon-image {\n\t\t\tmargin: 0;\n\t\t}\n\n\t\tp {\n\t\t\tpadding: 10px;\n\t\t}\n\t}\n}\n\n.fade-enter-active {\n\ttransition: opacity .3s ease-in-out;\n}\n\n.fade-enter-to {\n\topacity: 1;\n}\n\n.fade-enter {\n\topacity: 0;\n}\n"],sourceRoot:""}]),n.a=s},655:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=e(164),o=e(188);function i(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}function s(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function a(t,n){return(a=Object.setPrototypeOf||function(t,n){return t.__proto__=n,t})(t,n)}function c(t){var n=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var e,r=d(t);if(n){var o=d(this).constructor;e=Reflect.construct(r,arguments,o)}else e=r.apply(this,arguments);return l(this,e)}}function l(t,n){return!n||"object"!=typeof n&&"function"!=typeof n?function(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):n}function d(t){return(d=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}let u=function(t){!function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(n&&n.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),n&&a(t,n)}(d,t);var n,e,r,l=c(d);function d(){return i(this,d),l.apply(this,arguments)}return n=d,(e=[{key:"name",get:function(){return"doc"}},{key:"schema",get:function(){return{content:"block"}}},{key:"keys",value:function(){return{Tab:t=>((0,o.insertText)("\t")(t,this.editor.view.dispatch,this.editor.view),!0)}}}])&&s(n.prototype,e),r&&s(n,r),d}(r.Node);n.default=u},656:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=e(171),o=e(164),i=e(188),s=e(657),a=e(658);function c(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}function l(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function d(t,n){return(d=Object.setPrototypeOf||function(t,n){return t.__proto__=n,t})(t,n)}function u(t){var n=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var e,r=h(t);if(n){var o=h(this).constructor;e=Reflect.construct(r,arguments,o)}else e=r.apply(this,arguments);return p(this,e)}}function p(t,n){return!n||"object"!=typeof n&&"function"!=typeof n?function(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):n}function h(t){return(h=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}const A=0,f=1,C=(t,n)=>(0,s.findParentNode)((function(n){return n.type===t.nodes.list_item}))(n);let m=function(t){!function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(n&&n.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),n&&d(t,n)}(h,t);var n,e,r,p=u(h);function h(){return c(this,h),p.apply(this,arguments)}return n=h,(e=[{key:"defaultOptions",get:function(){return{nested:!0}}},{key:"schema",get:function(){return{attrs:{done:{default:!1},type:{default:A}},draggable:!1,content:"paragraph block*",toDOM:t=>{if(t.attrs.type===A)return["li",0];const n={class:"checkbox-item"},e={type:"checkbox",class:"",contenteditable:!1};return t.attrs.done&&(e.checked=!0,n.class+=" checked"),["li",n,["input",e],["label",0]]},parseDOM:[{priority:100,tag:"li",getAttrs:t=>{const n=t.querySelector("input[type=checkbox]");return{done:n&&n.checked,type:n?f:A}}}],toMarkdown:(t,n)=>{n.attrs.type===f&&t.write("[".concat(n.attrs.done?"x":" ","] ")),t.renderContent(n)}}}},{key:"commands",value:function({type:t,schema:n}){return{bullet_list_item:()=>(e,r,o)=>(0,i.toggleList)(n.nodes.bullet_list,t)(e,r,o),todo_item:()=>(n,e,r)=>{const o=n.schema,s=n.selection,a=s.$from,c=s.$to,l=a.blockRange(c);let d=n.tr,u=C(o,s);if(void 0===u&&((0,i.toggleList)(o.nodes.bullet_list,t)(n,t=>{d=t},r),u=C(o,d.selection)),!l||void 0===u)return!1;d.setNodeMarkup(u.pos,o.nodes.list_item,{type:u.node.attrs.type===f?A:f}),d.scrollIntoView(),e&&e(d)}}}},{key:"inputRules",value:function({type:t}){return[(0,i.wrappingInputRule)(/^\s*([-+*])\s(\[ ?\])\s$/,t,t=>({type:f})),(0,i.wrappingInputRule)(/^\s*([-+*])\s(\[(x|X)\])\s$/,t,t=>({type:f,done:!0})),(0,a.listInputRule)(/^\s*([-+*])\s([^\s[])$/,t)]}},{key:"plugins",get:function(){return[new o.Plugin({props:{handleClick:(t,n,e)=>{const r=t.state,o=r.schema,i=t.posAtCoords({left:e.clientX,top:e.clientY}),a=r.doc.resolve(i.pos),c=(0,s.findParentNodeClosestToPos)(a,(function(t){return t.type===o.nodes.list_item})),l="li"===e.target.tagName.toLowerCase();if(void 0===c||c.node.attrs.type!==f||!l)return;const d=r.tr;d.setNodeMarkup(c.pos,o.nodes.list_item,{done:!c.node.attrs.done,type:f}),t.dispatch(d)}}})]}}])&&l(n.prototype,e),r&&l(n,r),h}(r.ListItem);n.default=m},658:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),Object.defineProperty(n,"listInputRule",{enumerable:!0,get:function(){return o.default}});var r,o=(r=e(659))&&r.__esModule?r:{default:r}},659:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=
/*
 * @copyright Copyright (c) 2021 Jonas Meurer <jonas@freesources.org>
 *
 * @author Jonas Meurer <jonas@freesources.org>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
function(t,n,e){return new r.InputRule(t,(e,o,i,s)=>{const a=(0,r.wrappingInputRule)(t,n).handler(e,o,i,s);return o.length>=3&&a.insertText(o[2]),a})};var r=e(211)},660:function(t,n,e){"use strict";function r(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}function o(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function i(t,n){return(i=Object.setPrototypeOf||function(t,n){return t.__proto__=n,t})(t,n)}function s(t){var n=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var e,r=c(t);if(n){var o=c(this).constructor;e=Reflect.construct(r,arguments,o)}else e=r.apply(this,arguments);return a(this,e)}}function a(t,n){return!n||"object"!=typeof n&&"function"!=typeof n?function(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):n}function c(t){return(c=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;let l=function(t){!function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(n&&n.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),n&&i(t,n)}(l,t);var n,e,a,c=s(l);function l(){return r(this,l),c.apply(this,arguments)}return n=l,(e=[{key:"inputRules",value:function(){return[]}}])&&o(n.prototype,e),a&&o(n,a),l}(e(171).BulletList);n.default=l},719:function(t,n,e){var r={"./1c":[440,1],"./1c.js":[440,1],"./abnf":[441,2],"./abnf.js":[441,2],"./accesslog":[442,3],"./accesslog.js":[442,3],"./actionscript":[443,4],"./actionscript.js":[443,4],"./ada":[444,5],"./ada.js":[444,5],"./angelscript":[445,6],"./angelscript.js":[445,6],"./apache":[446,7],"./apache.js":[446,7],"./applescript":[447,8],"./applescript.js":[447,8],"./arcade":[448,9],"./arcade.js":[448,9],"./arduino":[449,10],"./arduino.js":[449,10],"./armasm":[450,11],"./armasm.js":[450,11],"./asciidoc":[451,12],"./asciidoc.js":[451,12],"./aspectj":[452,13],"./aspectj.js":[452,13],"./autohotkey":[453,14],"./autohotkey.js":[453,14],"./autoit":[454,15],"./autoit.js":[454,15],"./avrasm":[455,16],"./avrasm.js":[455,16],"./awk":[456,17],"./awk.js":[456,17],"./axapta":[457,18],"./axapta.js":[457,18],"./bash":[458,19],"./bash.js":[458,19],"./basic":[459,20],"./basic.js":[459,20],"./bnf":[460,21],"./bnf.js":[460,21],"./brainfuck":[461,22],"./brainfuck.js":[461,22],"./c":[463,23],"./c-like":[462,24],"./c-like.js":[462,24],"./c.js":[463,23],"./cal":[464,25],"./cal.js":[464,25],"./capnproto":[465,26],"./capnproto.js":[465,26],"./ceylon":[466,27],"./ceylon.js":[466,27],"./clean":[467,28],"./clean.js":[467,28],"./clojure":[469,29],"./clojure-repl":[468,30],"./clojure-repl.js":[468,30],"./clojure.js":[469,29],"./cmake":[470,31],"./cmake.js":[470,31],"./coffeescript":[471,32],"./coffeescript.js":[471,32],"./coq":[472,33],"./coq.js":[472,33],"./cos":[473,34],"./cos.js":[473,34],"./cpp":[474,35],"./cpp.js":[474,35],"./crmsh":[475,36],"./crmsh.js":[475,36],"./crystal":[476,37],"./crystal.js":[476,37],"./csharp":[477,38],"./csharp.js":[477,38],"./csp":[478,39],"./csp.js":[478,39],"./css":[479,40],"./css.js":[479,40],"./d":[480,41],"./d.js":[480,41],"./dart":[481,42],"./dart.js":[481,42],"./delphi":[482,43],"./delphi.js":[482,43],"./diff":[483,44],"./diff.js":[483,44],"./django":[484,45],"./django.js":[484,45],"./dns":[485,46],"./dns.js":[485,46],"./dockerfile":[486,47],"./dockerfile.js":[486,47],"./dos":[487,48],"./dos.js":[487,48],"./dsconfig":[488,49],"./dsconfig.js":[488,49],"./dts":[489,50],"./dts.js":[489,50],"./dust":[490,51],"./dust.js":[490,51],"./ebnf":[491,52],"./ebnf.js":[491,52],"./elixir":[492,53],"./elixir.js":[492,53],"./elm":[493,54],"./elm.js":[493,54],"./erb":[494,55],"./erb.js":[494,55],"./erlang":[496,56],"./erlang-repl":[495,57],"./erlang-repl.js":[495,57],"./erlang.js":[496,56],"./excel":[497,58],"./excel.js":[497,58],"./fix":[498,59],"./fix.js":[498,59],"./flix":[499,60],"./flix.js":[499,60],"./fortran":[500,61],"./fortran.js":[500,61],"./fsharp":[501,62],"./fsharp.js":[501,62],"./gams":[502,63],"./gams.js":[502,63],"./gauss":[503,64],"./gauss.js":[503,64],"./gcode":[504,65],"./gcode.js":[504,65],"./gherkin":[505,66],"./gherkin.js":[505,66],"./glsl":[506,67],"./glsl.js":[506,67],"./gml":[507,68],"./gml.js":[507,68],"./go":[508,69],"./go.js":[508,69],"./golo":[509,70],"./golo.js":[509,70],"./gradle":[510,71],"./gradle.js":[510,71],"./groovy":[511,72],"./groovy.js":[511,72],"./haml":[512,73],"./haml.js":[512,73],"./handlebars":[513,74],"./handlebars.js":[513,74],"./haskell":[514,75],"./haskell.js":[514,75],"./haxe":[515,76],"./haxe.js":[515,76],"./hsp":[516,77],"./hsp.js":[516,77],"./htmlbars":[517,78],"./htmlbars.js":[517,78],"./http":[518,79],"./http.js":[518,79],"./hy":[519,80],"./hy.js":[519,80],"./inform7":[520,81],"./inform7.js":[520,81],"./ini":[521,82],"./ini.js":[521,82],"./irpf90":[522,83],"./irpf90.js":[522,83],"./isbl":[523,84],"./isbl.js":[523,84],"./java":[524,85],"./java.js":[524,85],"./javascript":[525,86],"./javascript.js":[525,86],"./jboss-cli":[526,87],"./jboss-cli.js":[526,87],"./json":[527,88],"./json.js":[527,88],"./julia":[529,89],"./julia-repl":[528,90],"./julia-repl.js":[528,90],"./julia.js":[529,89],"./kotlin":[530,91],"./kotlin.js":[530,91],"./lasso":[531,92],"./lasso.js":[531,92],"./latex":[532,93],"./latex.js":[532,93],"./ldif":[533,94],"./ldif.js":[533,94],"./leaf":[534,95],"./leaf.js":[534,95],"./less":[535,96],"./less.js":[535,96],"./lisp":[536,97],"./lisp.js":[536,97],"./livecodeserver":[537,98],"./livecodeserver.js":[537,98],"./livescript":[538,99],"./livescript.js":[538,99],"./llvm":[539,100],"./llvm.js":[539,100],"./lsl":[540,101],"./lsl.js":[540,101],"./lua":[541,102],"./lua.js":[541,102],"./makefile":[542,103],"./makefile.js":[542,103],"./markdown":[543,104],"./markdown.js":[543,104],"./mathematica":[544,105],"./mathematica.js":[544,105],"./matlab":[545,106],"./matlab.js":[545,106],"./maxima":[546,107],"./maxima.js":[546,107],"./mel":[547,108],"./mel.js":[547,108],"./mercury":[548,109],"./mercury.js":[548,109],"./mipsasm":[549,110],"./mipsasm.js":[549,110],"./mizar":[550,111],"./mizar.js":[550,111],"./mojolicious":[551,112],"./mojolicious.js":[551,112],"./monkey":[552,113],"./monkey.js":[552,113],"./moonscript":[553,114],"./moonscript.js":[553,114],"./n1ql":[554,115],"./n1ql.js":[554,115],"./nginx":[555,116],"./nginx.js":[555,116],"./nim":[556,117],"./nim.js":[556,117],"./nix":[557,118],"./nix.js":[557,118],"./node-repl":[558,119],"./node-repl.js":[558,119],"./nsis":[559,120],"./nsis.js":[559,120],"./objectivec":[560,121],"./objectivec.js":[560,121],"./ocaml":[561,122],"./ocaml.js":[561,122],"./openscad":[562,123],"./openscad.js":[562,123],"./oxygene":[563,124],"./oxygene.js":[563,124],"./parser3":[564,125],"./parser3.js":[564,125],"./perl":[565,126],"./perl.js":[565,126],"./pf":[566,127],"./pf.js":[566,127],"./pgsql":[567,128],"./pgsql.js":[567,128],"./php":[569,129],"./php-template":[568,130],"./php-template.js":[568,130],"./php.js":[569,129],"./plaintext":[570,131],"./plaintext.js":[570,131],"./pony":[571,132],"./pony.js":[571,132],"./powershell":[572,133],"./powershell.js":[572,133],"./processing":[573,134],"./processing.js":[573,134],"./profile":[574,135],"./profile.js":[574,135],"./prolog":[575,136],"./prolog.js":[575,136],"./properties":[576,137],"./properties.js":[576,137],"./protobuf":[577,138],"./protobuf.js":[577,138],"./puppet":[578,139],"./puppet.js":[578,139],"./purebasic":[579,140],"./purebasic.js":[579,140],"./python":[581,141],"./python-repl":[580,142],"./python-repl.js":[580,142],"./python.js":[581,141],"./q":[582,143],"./q.js":[582,143],"./qml":[583,144],"./qml.js":[583,144],"./r":[584,145],"./r.js":[584,145],"./reasonml":[585,146],"./reasonml.js":[585,146],"./rib":[586,147],"./rib.js":[586,147],"./roboconf":[587,148],"./roboconf.js":[587,148],"./routeros":[588,149],"./routeros.js":[588,149],"./rsl":[589,150],"./rsl.js":[589,150],"./ruby":[590,151],"./ruby.js":[590,151],"./ruleslanguage":[591,152],"./ruleslanguage.js":[591,152],"./rust":[592,153],"./rust.js":[592,153],"./sas":[593,154],"./sas.js":[593,154],"./scala":[594,155],"./scala.js":[594,155],"./scheme":[595,156],"./scheme.js":[595,156],"./scilab":[596,157],"./scilab.js":[596,157],"./scss":[597,158],"./scss.js":[597,158],"./shell":[598,159],"./shell.js":[598,159],"./smali":[599,160],"./smali.js":[599,160],"./smalltalk":[600,161],"./smalltalk.js":[600,161],"./sml":[601,162],"./sml.js":[601,162],"./sqf":[602,163],"./sqf.js":[602,163],"./sql":[603,164],"./sql.js":[603,164],"./sql_more":[604,165],"./sql_more.js":[604,165],"./stan":[605,166],"./stan.js":[605,166],"./stata":[606,167],"./stata.js":[606,167],"./step21":[607,168],"./step21.js":[607,168],"./stylus":[608,169],"./stylus.js":[608,169],"./subunit":[609,170],"./subunit.js":[609,170],"./swift":[610,171],"./swift.js":[610,171],"./taggerscript":[611,172],"./taggerscript.js":[611,172],"./tap":[612,173],"./tap.js":[612,173],"./tcl":[613,174],"./tcl.js":[613,174],"./thrift":[614,175],"./thrift.js":[614,175],"./tp":[615,176],"./tp.js":[615,176],"./twig":[616,177],"./twig.js":[616,177],"./typescript":[617,178],"./typescript.js":[617,178],"./vala":[618,179],"./vala.js":[618,179],"./vbnet":[619,180],"./vbnet.js":[619,180],"./vbscript":[621,181],"./vbscript-html":[620,182],"./vbscript-html.js":[620,182],"./vbscript.js":[621,181],"./verilog":[622,183],"./verilog.js":[622,183],"./vhdl":[623,184],"./vhdl.js":[623,184],"./vim":[624,185],"./vim.js":[624,185],"./x86asm":[625,186],"./x86asm.js":[625,186],"./xl":[626,187],"./xl.js":[626,187],"./xml":[627,188],"./xml.js":[627,188],"./xquery":[628,189],"./xquery.js":[628,189],"./yaml":[629,190],"./yaml.js":[629,190],"./zephir":[630,191],"./zephir.js":[630,191]};function o(t){if(!e.o(r,t))return Promise.resolve().then((function(){var n=new Error("Cannot find module '"+t+"'");throw n.code="MODULE_NOT_FOUND",n}));var n=r[t],o=n[0];return e.e(n[1]).then((function(){return e.t(o,7)}))}o.keys=function(){return Object.keys(r)},o.id=719,t.exports=o},720:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),Object.defineProperty(n,"Keymap",{enumerable:!0,get:function(){return r.default}}),Object.defineProperty(n,"UserColor",{enumerable:!0,get:function(){return o.default}});var r=i(e(721)),o=i(e(722));function i(t){return t&&t.__esModule?t:{default:t}}},721:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=e(164);function o(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}function i(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function s(t,n){return(s=Object.setPrototypeOf||function(t,n){return t.__proto__=n,t})(t,n)}function a(t){var n=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var e,r=l(t);if(n){var o=l(this).constructor;e=Reflect.construct(r,arguments,o)}else e=r.apply(this,arguments);return c(this,e)}}function c(t,n){return!n||"object"!=typeof n&&"function"!=typeof n?function(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):n}function l(t){return(l=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}let d=function(t){!function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(n&&n.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),n&&s(t,n)}(d,t);var n,e,c,l=a(d);function d(){return o(this,d),l.apply(this,arguments)}return n=d,(e=[{key:"name",get:function(){return"customkeymap"}},{key:"keys",value:function({schema:t}){return this.options}},{key:"plugins",get:function(){return[new r.Plugin({props:{handleKeyDown(t,n){const e=n.key||n.keyCode;if((n.ctrlKey||n.metaKey)&&!n.shiftKey&&("f"===e||70===e))return n.stopPropagation(),window.dispatchEvent(n),!0}}})]}}])&&i(n.prototype,e),c&&i(n,c),d}(r.Extension);n.default=d},722:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r,o=e(164),i=e(177),s=(r=e(723))&&r.__esModule?r:{default:r},a=e(404);function c(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}function l(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function d(t,n){return(d=Object.setPrototypeOf||function(t,n){return t.__proto__=n,t})(t,n)}function u(t){var n=function(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){}))),!0}catch(t){return!1}}();return function(){var e,r=h(t);if(n){var o=h(this).constructor;e=Reflect.construct(r,arguments,o)}else e=r.apply(this,arguments);return p(this,e)}}function p(t,n){return!n||"object"!=typeof n&&"function"!=typeof n?function(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(t):n}function h(t){return(h=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}let A=function(t){!function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(n&&n.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),n&&d(t,n)}(h,t);var n,e,r,p=u(h);function h(){return c(this,h),p.apply(this,arguments)}return n=h,(e=[{key:"name",get:function(){return"users"}},{key:"defaultOptions",get:function(){return{clientID:0,color:t=>"#"+Math.floor(Math.abs(16777215*Math.sin(t))%16777215).toString(16)+"aa",name:t=>"Unknown user "+t}}},{key:"plugins",get:function(){return[new o.Plugin({clientID:this.options.clientID,color:this.options.color,name:this.options.name,state:{init:(t,n)=>({tracked:new s.default([new a.Span(0,n.doc.content.size,null)],[],[],[]),deco:i.DecorationSet.empty}),apply(t,n,e,r){let{tracked:o,decos:s}=n,a=this.getState(e).tracked;return t.docChanged&&(t.getMeta("clientID")||t.setMeta("clientID",t.steps.map(t=>this.spec.clientID)),o=o.applyTransform(t),a=o),s=a.blameMap.map(t=>{const n=t.author;return i.Decoration.inline(t.from,t.to,{class:"author-annotation",style:"background-color: "+this.spec.color(n)+"66;",title:this.spec.name(n)})}).filter(t=>null!==t),{tracked:o,deco:i.DecorationSet.create(r.doc,s)}}},props:{decorations(t){return this.getState(t).deco}}})]}}])&&l(n.prototype,e),r&&l(n,r),h}(o.Extension);n.default=A},723:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var r=e(404);function o(t,n){for(var e=0;e<n.length;e++){var r=n[e];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,r.key,r)}}function i(t,n,e,o){if(n>=e)return;let i,s=0;for(;s<t.length;s++)if(i=t[s],i.author===o){if(i.to>=n)break}else if(i.to>n){if(i.from<n){const o=new r.Span(i.from,n,i.author);i.to>e?t.splice(s++,0,o):t[s++]=o}break}for(;i=t[s];)if(i.author===o){if(i.from>e)break;n=Math.min(n,i.from),e=Math.max(e,i.to),t.splice(s,1)}else{if(i.from>=e)break;if(i.to>e){t[s]=new r.Span(e,i.to,i.author);break}t.splice(s,1)}t.splice(s,0,new r.Span(n,e,o))}let s=function(){function t(n){!function(t,n){if(!(t instanceof n))throw new TypeError("Cannot call a class as a function")}(this,t),this.blameMap=n}var n,e,s;return n=t,(e=[{key:"applyTransform",value:function(n){var e;const o=null!==(e=n.getMeta("clientID"))&&void 0!==e?e:n.steps.map(t=>"self");return new t(function(t,n,e){const o=[],s=n.mapping;for(let n=0;n<t.length;n++){const e=t[n],i=s.map(e.from,1),a=s.map(e.to,-1);i<a&&o.push(new r.Span(i,a,e.author))}for(let t=0;t<s.maps.length;t++){const n=s.maps[t],r=s.slice(t+1);n.forEach((n,s,a,c)=>{i(o,r.map(a,1),r.map(c,-1),e[t])})}return o}(this.blameMap,n,o))}}])&&o(n.prototype,e),s&&o(n,s),t}();n.default=s},724:function(t,n,e){"use strict";Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;
/*
 * @copyright Copyright (c) 2019 Julius Härtl <jus@bitgrid.net>
 *
 * @author Julius Härtl <jus@bitgrid.net>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
var r={data(){return{isMobile:this._isMobile()}},beforeMount(){window.addEventListener("resize",this._onResize)},beforeDestroy(){window.removeEventListener("resize",this._onResize)},methods:{_onResize(){this.isMobile=this._isMobile()},_isMobile:()=>document.documentElement.clientWidth<768}};n.default=r},818:function(t,n,e){"use strict";var r=e(20),o=e.n(r),i=e(21),s=e.n(i)()(o.a);s.push([t.i,"#editor-container[data-v-84a83934]{display:block;width:100%;max-width:100%;height:100%;left:0;top:50px;margin:0 auto;position:relative;background-color:var(--color-main-background)}#editor-wrapper[data-v-84a83934]{display:flex;width:100%;height:100%;overflow:hidden;position:absolute}#editor-wrapper.show-color-annotations[data-v-84a83934] .author-annotation{padding-top:2px;padding-bottom:2px}#editor-wrapper[data-v-84a83934]:not(.show-color-annotations) .author-annotation{background-color:transparent !important;color:var(--color-main-text) !important}#editor-wrapper .ProseMirror[data-v-84a83934]{margin-top:0 !important}#editor-wrapper.icon-loading #editor[data-v-84a83934]{opacity:0.3}#editor[data-v-84a83934],.editor[data-v-84a83934]{background:var(--color-main-background);color:var(--color-main-text);background-clip:padding-box;border-radius:var(--border-radius);padding:0;position:relative;overflow-y:auto;overflow-x:hidden;width:100%}.document-status[data-v-84a83934]{z-index:1010;position:relative;background-color:var(--color-main-background)}.document-status .msg[data-v-84a83934]{padding:12px;background-position:8px center;color:var(--color-text-maxcontrast)}.document-status .msg.icon-error[data-v-84a83934]{padding-left:30px}.document-status .msg .button[data-v-84a83934]{margin-left:8px}.save-status[data-v-84a83934]{display:inline-flex;padding:0;text-overflow:ellipsis;color:var(--color-text-lighter);position:relative;top:10px;min-width:85px}.save-status.error[data-v-84a83934]{background-color:var(--color-error);color:var(--color-main-background);border-radius:3px}#editor-container #editor-wrapper.has-conflicts[data-v-84a83934]{height:calc(100% - 50px)}#editor-container #editor-wrapper.has-conflicts #editor[data-v-84a83934],#editor-container #editor-wrapper.has-conflicts #read-only-editor[data-v-84a83934]{width:50%;height:100%}#editor-session-list[data-v-84a83934]{display:flex}#editor-session-list input[data-v-84a83934],#editor-session-list div[data-v-84a83934]{vertical-align:middle;margin-left:3px}.editor__content[data-v-84a83934]{max-width:670px;margin:auto;position:relative}#body-public[data-v-84a83934]{height:auto}#files-public-content #editor-container[data-v-84a83934]{top:0;width:100%}#files-public-content #editor-container #editor[data-v-84a83934] .menubar{position:sticky;top:0px;width:100%}#files-public-content #editor-container #editor[data-v-84a83934]{overflow:auto;z-index:20}#files-public-content #editor-container .has-conflicts #editor[data-v-84a83934]{padding-top:0}.ie #editor[data-v-84a83934] .menubar{position:fixed;top:50px;width:100%}.ie .editor__content[data-v-84a83934] .ProseMirror{padding-top:50px}\n","",{version:3,sources:["webpack://./src/components/EditorWrapper.vue"],names:[],mappings:"AA+fA,mCACC,aAAc,CACd,UAAW,CACX,cAAe,CACf,WAAY,CACZ,MAAO,CACP,QAAS,CACT,aAAc,CACd,iBAAkB,CAClB,6CAA8C,CAC9C,iCAGA,YAAa,CACb,UAAW,CACX,WAAY,CACZ,eAAgB,CAChB,iBAAkB,CALnB,2EAQE,eAAgB,CAChB,kBAAmB,CATrB,iFAaE,uCAAwC,CACxC,uCAAwC,CAd1C,8CAkBE,uBAAwB,CAlB1B,sDAsBG,WAAY,CACZ,kDAKF,uCAAwC,CACxC,4BAA6B,CAC7B,2BAA4B,CAC5B,kCAAmC,CACnC,SAAU,CACV,iBAAkB,CAClB,eAAgB,CAChB,iBAAkB,CAClB,UAAW,CACX,kCAGA,YAAa,CACb,iBAAkB,CAClB,6CAA8C,CAH/C,uCAME,YAAa,CACb,8BAA+B,CAC/B,mCAAoC,CARtC,kDAWG,iBAAkB,CAXrB,+CAeG,eAAgB,CAChB,8BAKF,mBAAoB,CACpB,SAAU,CACV,sBAAuB,CACvB,+BAAgC,CAChC,iBAAkB,CAClB,QAAS,CACT,cAAe,CAPhB,oCAUE,mCAAoC,CACpC,kCAAmC,CACnC,iBAAkB,CAClB,iEAID,wBAAyB,CAD1B,4JAIE,SAAU,CACV,WAAY,CACZ,sCAID,YAAa,CADd,sFAIE,qBAAsB,CACtB,eAAgB,CAChB,kCAID,eAAgB,CAChB,WAAY,CACZ,iBAAkB,CAClB,8BAGA,WAAY,CACZ,yDAIC,KAAM,CACN,UAAW,CAHb,0EAMG,eAAgB,CAChB,OAAQ,CACR,UAAW,CARd,iEAYG,aAAc,CACd,UAAW,CAbd,gFAgBG,aAAc,CACd,sCAOD,cAAe,CACf,QAAS,CACT,UAAW,CALb,mDAQE,gBAAiB",sourcesContent:["\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n#editor-container {\n\tdisplay: block;\n\twidth: 100%;\n\tmax-width: 100%;\n\theight: 100%;\n\tleft: 0;\n\ttop: 50px;\n\tmargin: 0 auto;\n\tposition: relative;\n\tbackground-color: var(--color-main-background);\n}\n\n#editor-wrapper {\n\tdisplay: flex;\n\twidth: 100%;\n\theight: 100%;\n\toverflow: hidden;\n\tposition: absolute;\n\n\t&.show-color-annotations::v-deep .author-annotation {\n\t\tpadding-top: 2px;\n\t\tpadding-bottom: 2px;\n\t}\n\n\t&:not(.show-color-annotations)::v-deep .author-annotation {\n\t\tbackground-color: transparent !important;\n\t\tcolor: var(--color-main-text) !important;\n\t}\n\n\t.ProseMirror {\n\t\tmargin-top: 0 !important;\n\t}\n\t&.icon-loading {\n\t\t#editor {\n\t\t\topacity: 0.3;\n\t\t}\n\t}\n}\n\n#editor, .editor {\n\tbackground: var(--color-main-background);\n\tcolor: var(--color-main-text);\n\tbackground-clip: padding-box;\n\tborder-radius: var(--border-radius);\n\tpadding: 0;\n\tposition: relative;\n\toverflow-y: auto;\n\toverflow-x: hidden;\n\twidth: 100%;\n}\n\n.document-status {\n\tz-index: 1010;\n\tposition: relative;\n\tbackground-color: var(--color-main-background);\n\n\t.msg {\n\t\tpadding: 12px;\n\t\tbackground-position: 8px center;\n\t\tcolor: var(--color-text-maxcontrast);\n\n\t\t&.icon-error {\n\t\t\tpadding-left: 30px;\n\t\t}\n\n\t\t.button {\n\t\t\tmargin-left: 8px;\n\t\t}\n\t}\n}\n\n.save-status {\n\tdisplay: inline-flex;\n\tpadding: 0;\n\ttext-overflow: ellipsis;\n\tcolor: var(--color-text-lighter);\n\tposition: relative;\n\ttop: 10px;\n\tmin-width: 85px;\n\n\t&.error {\n\t\tbackground-color: var(--color-error);\n\t\tcolor: var(--color-main-background);\n\t\tborder-radius: 3px;\n\t}\n}\n\n#editor-container #editor-wrapper.has-conflicts {\n\theight: calc(100% - 50px);\n\n\t#editor, #read-only-editor {\n\t\twidth: 50%;\n\t\theight: 100%;\n\t}\n}\n\n#editor-session-list {\n\tdisplay: flex;\n\n\tinput, div {\n\t\tvertical-align: middle;\n\t\tmargin-left: 3px;\n\t}\n}\n\n.editor__content {\n\tmax-width: 670px;\n\tmargin: auto;\n\tposition: relative;\n}\n\n#body-public {\n\theight: auto;\n}\n\n#files-public-content {\n\t#editor-container {\n\t\ttop: 0;\n\t\twidth: 100%;\n\n\t\t#editor::v-deep .menubar {\n\t\t\tposition: sticky;\n\t\t\ttop: 0px;\n\t\t\twidth: 100%;\n\t\t}\n\n\t\t#editor {\n\t\t\toverflow: auto;\n\t\t\tz-index: 20;\n\t\t}\n\t\t.has-conflicts #editor {\n\t\t\tpadding-top: 0;\n\t\t}\n\t}\n}\n\n.ie {\n\t#editor::v-deep .menubar {\n\t\t// sticky position is not working as body is our scroll container\n\t\tposition: fixed;\n\t\ttop: 50px;\n\t\twidth: 100%;\n\t}\n\t.editor__content::v-deep .ProseMirror {\n\t\tpadding-top: 50px;\n\t}\n}\n\n"],sourceRoot:""}]),n.a=s},819:function(t,n,e){"use strict";var r=e(20),o=e.n(r),i=e(21),s=e.n(i),a=e(224),c=e.n(a),l=e(225),d=s()(o.a),u=c()(l.a);d.push([t.i,'.modal-container #editor-container{position:absolute}.ProseMirror-hideselection *::selection{background:transparent;color:var(--color-main-text)}.ProseMirror-hideselection *::-moz-selection{background:transparent;color:var(--color-main-text)}.ProseMirror-hideselection{caret-color:transparent;color:var(--color-main-text)}.ProseMirror-selectednode{outline:2px solid #8cf}li.ProseMirror-selectednode{outline:none}li.ProseMirror-selectednode:after{content:"";position:absolute;left:-32px;right:-2px;top:-2px;bottom:-2px;border:2px solid #8cf;pointer-events:none}.has-conflicts .ProseMirror-menubar,#editor-wrapper.icon-loading .ProseMirror-menubar{display:none}.ProseMirror-gapcursor{display:none;pointer-events:none;position:absolute}.ProseMirror-gapcursor:after{content:"";display:block;position:absolute;top:-2px;width:20px;border-top:1px solid var(--color-main-text);animation:ProseMirror-cursor-blink 1.1s steps(2, start) infinite}@keyframes ProseMirror-cursor-blink{to{visibility:hidden}}#editor-wrapper div.ProseMirror{margin-top:44px;height:100%;position:relative;word-wrap:break-word;white-space:pre-wrap;-webkit-font-variant-ligatures:none;font-variant-ligatures:none;padding:4px 8px 200px 14px;line-height:150%;font-size:14px;outline:none}#editor-wrapper div.ProseMirror[contenteditable=true],#editor-wrapper div.ProseMirror[contenteditable=false],#editor-wrapper div.ProseMirror [contenteditable=true],#editor-wrapper div.ProseMirror [contenteditable=false]{border:none !important;width:100%;background-color:transparent;color:var(--color-main-text);opacity:1;-webkit-user-select:text;user-select:text;font-size:14px}#editor-wrapper div.ProseMirror .checkbox-item{display:flex;align-items:start;margin-left:-23px}#editor-wrapper div.ProseMirror .checkbox-item input[type=checkbox]{display:none}#editor-wrapper div.ProseMirror .checkbox-item:before{content:\'\';vertical-align:middle;margin:3px 6px 3px 2px;border:1px solid var(--color-text-maxcontrast);position:relative;display:block;border-radius:var(--border-radius);height:14px;width:14px;box-shadow:none !important;background-position:center;cursor:pointer}#editor-wrapper div.ProseMirror .checkbox-item.checked:before{background-image:url('+u+');background-color:var(--color-primary-element);border-color:var(--color-primary-element)}#editor-wrapper div.ProseMirror .checkbox-item label{display:block;flex-grow:1;max-width:calc(100% - 28px)}#editor-wrapper div.ProseMirror>*:first-child{margin-top:10px}#editor-wrapper div.ProseMirror a{color:var(--color-primary-element);text-decoration:underline;padding:.5em 0}#editor-wrapper div.ProseMirror p{margin-bottom:1em;line-height:150%}#editor-wrapper div.ProseMirror em{font-style:italic}#editor-wrapper div.ProseMirror h1,#editor-wrapper div.ProseMirror h2,#editor-wrapper div.ProseMirror h3,#editor-wrapper div.ProseMirror h4,#editor-wrapper div.ProseMirror h5,#editor-wrapper div.ProseMirror h6{font-weight:600;line-height:120%;margin-top:24px;margin-bottom:12px;color:var(--color-main-text)}#editor-wrapper div.ProseMirror h1{font-size:36px;margin-top:48px}#editor-wrapper div.ProseMirror h2{font-size:30px;margin-top:48px}#editor-wrapper div.ProseMirror h3{font-size:24px}#editor-wrapper div.ProseMirror h4{font-size:21px}#editor-wrapper div.ProseMirror h5{font-size:17px}#editor-wrapper div.ProseMirror h6{font-size:14px}#editor-wrapper div.ProseMirror img{cursor:default;max-width:100%}#editor-wrapper div.ProseMirror hr{padding:2px 0;border:none;margin:3em 0;width:100%}#editor-wrapper div.ProseMirror hr:after{content:"";display:block;height:1px;background-color:var(--color-border-dark);line-height:2px}#editor-wrapper div.ProseMirror pre{white-space:pre;overflow-x:auto;background-color:var(--color-background-dark);border-radius:var(--border-radius);padding:1em 1.3em;margin-bottom:1em}#editor-wrapper div.ProseMirror p code{background-color:var(--color-background-dark);border-radius:var(--border-radius);padding:.1em .3em}#editor-wrapper div.ProseMirror li{position:relative;padding-left:3px}#editor-wrapper div.ProseMirror li p{margin-bottom:0.5em}#editor-wrapper div.ProseMirror ul,#editor-wrapper div.ProseMirror ol{padding-left:10px;margin-left:10px;margin-bottom:1em}#editor-wrapper div.ProseMirror ul li{list-style-type:disc}#editor-wrapper div.ProseMirror ul>li>ul>li{list-style-type:circle}#editor-wrapper div.ProseMirror ul>li>ul>li ul li{list-style-type:square}#editor-wrapper div.ProseMirror blockquote{padding-left:1em;border-left:4px solid var(--color-primary-element);color:var(--color-text-maxcontrast);margin-left:0;margin-right:0}#editor-wrapper .ProseMirror-focused .ProseMirror-gapcursor{display:block}#editor-wrapper .editor__content p.is-empty:first-child::before{content:attr(data-empty-text);float:left;color:var(--color-text-maxcontrast);pointer-events:none;height:0}#editor-wrapper:not(.richEditor) .ProseMirror pre{background-color:var(--color-main-background)}#editor-wrapper:not(.richEditor) .ProseMirror pre::before{content:attr(data-language);text-transform:uppercase;display:block;text-align:right;font-weight:bold;font-size:0.6rem}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-comment,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-quote{color:#999999}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-variable,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-template-variable,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-attribute,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-tag,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-name,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-regexp,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-link,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-selector-id,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-selector-class{color:#f2777a}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-number,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-meta,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-built_in,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-builtin-name,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-literal,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-type,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-params{color:#f99157}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-string,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-symbol,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-bullet{color:#99cc99}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-title,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-section{color:#ffcc66}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-keyword,#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-selector-tag{color:#6699cc}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-emphasis{font-style:italic}#editor-wrapper:not(.richEditor) .ProseMirror pre code .hljs-strong{font-weight:700}#files-public-content{height:100%}\n',"",{version:3,sources:["webpack://./css/style.scss","webpack://./src/components/EditorWrapper.vue","webpack://./css/prosemirror.scss"],names:[],mappings:"AAAA,mCACE,iBAAkB,CACnB,wCAEyC,sBAAuB,CAAE,4BAA6B,CAAI,6CACrD,sBAAuB,CAAE,4BAA6B,CAAI,2BAC5E,uBAAwB,CAAE,4BAA6B,CAAI,0BAGtF,sBAAuB,CACxB,4BAIC,YAAa,CACd,kCAGC,UAAW,CACX,iBAAkB,CAClB,UAAW,CACX,UAAW,CAAE,QAAS,CAAE,WAAY,CACpC,qBAAsB,CACtB,mBAAoB,CACrB,sFAKG,YAAa,CACd,uBAID,YAAa,CACb,mBAAoB,CACpB,iBAAkB,CACnB,6BAGC,UAAW,CACX,aAAc,CACd,iBAAkB,CAClB,QAAS,CACT,UAAW,CACX,2CAA4C,CAC5C,gEAAiE,CAClE,oCAGC,GACE,iBAAkB,CAAA,CComBtB,gCCrpBC,eAAgB,CAChB,WAAY,CACZ,iBAAkB,CAClB,oBAAqB,CACrB,oBAAqB,CACrB,mCAAoC,CACpC,2BAA4B,CAC5B,0BAA2B,CAC3B,gBAAiB,CACjB,cAAe,CACf,YAAa,CD2oBd,4NCroBE,sBAAuB,CACvB,UAAW,CACX,4BAA6B,CAC7B,4BAA6B,CAC7B,SAAU,CACV,wBAAyB,CACzB,gBAAiB,CACjB,cAAe,CD8nBjB,+CC1nBE,YAAa,CACb,iBAAkB,CAElB,iBAAkB,CDunBpB,oECpnBG,YAAa,CDonBhB,sDCjnBG,UAAW,CACX,qBAAsB,CACtB,sBAAuB,CACvB,8CAA+C,CAC/C,iBAAkB,CAClB,aAAc,CACd,kCAAmC,CACnC,WAAY,CACZ,UAAW,CACX,0BAA2B,CAC3B,0BAA2B,CAC3B,cAAe,CDsmBlB,8DCnmBG,wDAAoD,CACpD,6CAA8C,CAC9C,yCAA0C,CDimB7C,qDC9lBG,aAAc,CACd,WAAY,CACZ,2BAA4B,CD4lB/B,8CCvlBE,eAAgB,CDulBlB,kCCnlBE,kCAAmC,CACnC,yBAA0B,CAC1B,cAAe,CDilBjB,kCC7kBE,iBAAkB,CAClB,gBAAiB,CD4kBnB,mCCxkBE,iBAAkB,CDwkBpB,kNC/jBE,eAAgB,CAChB,gBAAiB,CACjB,eAAgB,CAChB,kBAAmB,CACnB,4BAA6B,CD2jB/B,mCCvjBE,cAAe,CACf,eAAgB,CDsjBlB,mCCljBE,cAAe,CACf,eAAgB,CDijBlB,mCC7iBE,cAAe,CD6iBjB,mCCziBE,cAAe,CDyiBjB,mCCriBE,cAAe,CDqiBjB,mCCjiBE,cAAe,CDiiBjB,oCC7hBE,cAAe,CACf,cAAe,CD4hBjB,mCCxhBE,aAAc,CACd,WAAY,CACZ,YAAa,CACb,UAAW,CDqhBb,yCCjhBE,UAAW,CACX,aAAc,CACd,UAAW,CACX,yCAA0C,CAC1C,eAAgB,CD6gBlB,oCCzgBE,eAAgB,CAChB,eAAgB,CAChB,6CAA8C,CAC9C,kCAAmC,CACnC,iBAAkB,CAClB,iBAAkB,CDogBpB,uCChgBE,6CAA8C,CAC9C,kCAAmC,CACnC,iBAAkB,CD8fpB,mCC1fE,iBAAkB,CAClB,gBAAiB,CDyfnB,qCCtfG,mBAAoB,CDsfvB,sECjfE,iBAAkB,CAClB,gBAAiB,CACjB,iBAAkB,CD+epB,sCC3eE,oBAAqB,CD2evB,4CCteE,sBAAuB,CDsezB,kDCjeE,sBAAuB,CDiezB,2CC7dE,gBAAiB,CACjB,kDAAmD,CACnD,mCAAoC,CACpC,aAAc,CACd,cAAe,CDydjB,4DCndC,aAAc,CDmdf,gEC/cC,6BAA8B,CAC9B,UAAW,CACX,mCAAoC,CACpC,mBAAoB,CACpB,QAAS,CD2cV,kDAKG,6CAA8C,CALjD,0DAQI,2BAA4B,CAC5B,wBAAyB,CACzB,aAAc,CACd,gBAAiB,CACjB,gBAAiB,CACjB,gBAAiB,CAbrB,wIAkBK,aAAc,CAlBnB,0nBA6BK,aAAc,CA7BnB,ieAsCK,aAAc,CAtCnB,4MA2CK,aAAc,CA3CnB,wIA+CK,aAAc,CA/CnB,+IAmDK,aAAc,CAnDnB,sEAsDK,iBAAkB,CAtDvB,oEAyDK,eAAgB,CAChB,sBASJ,WAAY",sourcesContent:['.modal-container #editor-container {\n  position: absolute;\n}\n\n.ProseMirror-hideselection *::selection { background: transparent; color: var(--color-main-text); }\n.ProseMirror-hideselection *::-moz-selection { background: transparent; color: var(--color-main-text); }\n.ProseMirror-hideselection { caret-color: transparent; color: var(--color-main-text); }\n\n.ProseMirror-selectednode {\n  outline: 2px solid #8cf;\n}\n\n/* Make sure li selections wrap around markers */\nli.ProseMirror-selectednode {\n  outline: none;\n}\n\nli.ProseMirror-selectednode:after {\n  content: "";\n  position: absolute;\n  left: -32px;\n  right: -2px; top: -2px; bottom: -2px;\n  border: 2px solid #8cf;\n  pointer-events: none;\n}\n\n.has-conflicts,\n#editor-wrapper.icon-loading {\n  .ProseMirror-menubar {\n    display: none;\n  }\n}\n\n.ProseMirror-gapcursor {\n  display: none;\n  pointer-events: none;\n  position: absolute;\n}\n\n.ProseMirror-gapcursor:after {\n  content: "";\n  display: block;\n  position: absolute;\n  top: -2px;\n  width: 20px;\n  border-top: 1px solid var(--color-main-text);\n  animation: ProseMirror-cursor-blink 1.1s steps(2, start) infinite;\n}\n\n@keyframes ProseMirror-cursor-blink {\n  to {\n    visibility: hidden;\n  }\n}\n',"\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n@import './../../css/style';\n\n#editor-wrapper {\n\t@import './../../css/prosemirror';\n\n\t&:not(.richEditor) .ProseMirror {\n\t\tpre {\n\t\t\tbackground-color: var(--color-main-background);\n\n\t\t\t&::before {\n\t\t\t\tcontent: attr(data-language);\n\t\t\t\ttext-transform: uppercase;\n\t\t\t\tdisplay: block;\n\t\t\t\ttext-align: right;\n\t\t\t\tfont-weight: bold;\n\t\t\t\tfont-size: 0.6rem;\n\t\t\t}\n\t\t\tcode {\n\t\t\t\t.hljs-comment,\n\t\t\t\t.hljs-quote {\n\t\t\t\t\tcolor: #999999;\n\t\t\t\t}\n\t\t\t\t.hljs-variable,\n\t\t\t\t.hljs-template-variable,\n\t\t\t\t.hljs-attribute,\n\t\t\t\t.hljs-tag,\n\t\t\t\t.hljs-name,\n\t\t\t\t.hljs-regexp,\n\t\t\t\t.hljs-link,\n\t\t\t\t.hljs-selector-id,\n\t\t\t\t.hljs-selector-class {\n\t\t\t\t\tcolor: #f2777a;\n\t\t\t\t}\n\t\t\t\t.hljs-number,\n\t\t\t\t.hljs-meta,\n\t\t\t\t.hljs-built_in,\n\t\t\t\t.hljs-builtin-name,\n\t\t\t\t.hljs-literal,\n\t\t\t\t.hljs-type,\n\t\t\t\t.hljs-params {\n\t\t\t\t\tcolor: #f99157;\n\t\t\t\t}\n\t\t\t\t.hljs-string,\n\t\t\t\t.hljs-symbol,\n\t\t\t\t.hljs-bullet {\n\t\t\t\t\tcolor: #99cc99;\n\t\t\t\t}\n\t\t\t\t.hljs-title,\n\t\t\t\t.hljs-section {\n\t\t\t\t\tcolor: #ffcc66;\n\t\t\t\t}\n\t\t\t\t.hljs-keyword,\n\t\t\t\t.hljs-selector-tag {\n\t\t\t\t\tcolor: #6699cc;\n\t\t\t\t}\n\t\t\t\t.hljs-emphasis {\n\t\t\t\t\tfont-style: italic;\n\t\t\t\t}\n\t\t\t\t.hljs-strong {\n\t\t\t\t\tfont-weight: 700;\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t}\n}\n\n// Required in order to make the public pages behave the same if talk is enabled or not\n// as Talk overwrites the public page styles and changes the DOM layout for the sidebar injection\n#files-public-content {\n\theight: 100%;\n}\n","/* Document rendering styles */\ndiv.ProseMirror {\n\tmargin-top: 44px;\n\theight: 100%;\n\tposition: relative;\n\tword-wrap: break-word;\n\twhite-space: pre-wrap;\n\t-webkit-font-variant-ligatures: none;\n\tfont-variant-ligatures: none;\n\tpadding: 4px 8px 200px 14px;\n\tline-height: 150%;\n\tfont-size: 14px;\n\toutline: none;\n\n\t&[contenteditable=true],\n\t&[contenteditable=false],\n\t[contenteditable=true],\n\t[contenteditable=false] {\n\t\tborder: none !important;\n\t\twidth: 100%;\n\t\tbackground-color: transparent;\n\t\tcolor: var(--color-main-text);\n\t\topacity: 1;\n\t\t-webkit-user-select: text;\n\t\tuser-select: text;\n\t\tfont-size: 14px;\n\t}\n\n\t.checkbox-item {\n\t\tdisplay: flex;\n\t\talign-items: start;\n\t\t// Left-align with list item text\n\t\tmargin-left: -23px;\n\n\t\tinput[type=checkbox] {\n\t\t\tdisplay: none;\n\t\t}\n\t\t&:before {\n\t\t\tcontent: '';\n\t\t\tvertical-align: middle;\n\t\t\tmargin: 3px 6px 3px 2px;\n\t\t\tborder: 1px solid var(--color-text-maxcontrast);\n\t\t\tposition: relative;\n\t\t\tdisplay: block;\n\t\t\tborder-radius: var(--border-radius);\n\t\t\theight: 14px;\n\t\t\twidth: 14px;\n\t\t\tbox-shadow: none !important;\n\t\t\tbackground-position: center;\n\t\t\tcursor: pointer;\n\t\t}\n\t\t&.checked:before {\n\t\t\tbackground-image: url('../../img/checkbox-mark.svg');\n\t\t\tbackground-color: var(--color-primary-element);\n\t\t\tborder-color: var(--color-primary-element);\n\t\t}\n\t\tlabel {\n\t\t\tdisplay: block;\n\t\t\tflex-grow: 1;\n\t\t\tmax-width: calc(100% - 28px);\n\t\t}\n\t}\n\n\t> *:first-child {\n\t\tmargin-top: 10px;\n\t}\n\n\ta {\n\t\tcolor: var(--color-primary-element);\n\t\ttext-decoration: underline;\n\t\tpadding: .5em 0;\n\t}\n\n\tp {\n\t\tmargin-bottom: 1em;\n\t\tline-height: 150%;\n\t}\n\n\tem {\n\t\tfont-style: italic;\n\t}\n\n\th1,\n\th2,\n\th3,\n\th4,\n\th5,\n\th6 {\n\t\tfont-weight: 600;\n\t\tline-height: 120%;\n\t\tmargin-top: 24px;\n\t\tmargin-bottom: 12px;\n\t\tcolor: var(--color-main-text);\n\t}\n\n\th1 {\n\t\tfont-size: 36px;\n\t\tmargin-top: 48px;\n\t}\n\n\th2 {\n\t\tfont-size: 30px;\n\t\tmargin-top: 48px;\n\t}\n\n\th3 {\n\t\tfont-size: 24px;\n\t}\n\n\th4 {\n\t\tfont-size: 21px;\n\t}\n\n\th5 {\n\t\tfont-size: 17px;\n\t}\n\n\th6 {\n\t\tfont-size: 14px;\n\t}\n\n\timg {\n\t\tcursor: default;\n\t\tmax-width: 100%;\n\t}\n\n\thr {\n\t\tpadding: 2px 0;\n\t\tborder: none;\n\t\tmargin: 3em 0;\n\t\twidth: 100%;\n\t}\n\n\thr:after {\n\t\tcontent: \"\";\n\t\tdisplay: block;\n\t\theight: 1px;\n\t\tbackground-color: var(--color-border-dark);\n\t\tline-height: 2px;\n\t}\n\n\tpre {\n\t\twhite-space: pre;\n\t\toverflow-x: auto;\n\t\tbackground-color: var(--color-background-dark);\n\t\tborder-radius: var(--border-radius);\n\t\tpadding: 1em 1.3em;\n\t\tmargin-bottom: 1em;\n\t}\n\n\tp code {\n\t\tbackground-color: var(--color-background-dark);\n\t\tborder-radius: var(--border-radius);\n\t\tpadding: .1em .3em;\n\t}\n\n\tli {\n\t\tposition: relative;\n\t\tpadding-left: 3px;\n\n\t\tp {\n\t\t\tmargin-bottom: 0.5em;\n\t\t}\n\t}\n\n\tul, ol {\n\t\tpadding-left: 10px;\n\t\tmargin-left: 10px;\n\t\tmargin-bottom: 1em;\n\t}\n\n\tul li {\n\t\tlist-style-type: disc;\n\t}\n\n\t// Second-level list entries\n\tul > li > ul > li {\n\t\tlist-style-type: circle;\n\t}\n\n\t// Third-level and further down list entries\n\tul > li > ul > li ul li {\n\t\tlist-style-type: square;\n\t}\n\n\tblockquote {\n\t\tpadding-left: 1em;\n\t\tborder-left: 4px solid var(--color-primary-element);\n\t\tcolor: var(--color-text-maxcontrast);\n\t\tmargin-left: 0;\n\t\tmargin-right: 0;\n\t}\n\n}\n\n.ProseMirror-focused .ProseMirror-gapcursor {\n\tdisplay: block;\n}\n\n.editor__content p.is-empty:first-child::before {\n\tcontent: attr(data-empty-text);\n\tfloat: left;\n\tcolor: var(--color-text-maxcontrast);\n\tpointer-events: none;\n\theight: 0;\n}\n"],sourceRoot:""}]),n.a=d},820:function(t,n,e){"use strict";var r=e(20),o=e.n(r),i=e(21),s=e.n(i)()(o.a);s.push([t.i,"body[data-v-3ea77884]{position:fixed}#direct-editor[data-v-3ea77884]{width:100%;height:100%;position:fixed;overflow:hidden}#direct-editor[data-v-3ea77884] #editor-container{height:100%;top:0}#direct-editor[data-v-3ea77884] #editor-wrapper div.ProseMirror{margin-top:0}pre[data-v-3ea77884]{width:100%;max-width:700px;margin:auto;background-color:var(--color-background-dark)}button[data-v-3ea77884]{width:44px;height:44px;margin:0;background-size:16px;border:0;background-color:transparent;opacity:.5;color:var(--color-main-text);background-position:center center;vertical-align:top}button[data-v-3ea77884]:hover,button[data-v-3ea77884]:focus,button[data-v-3ea77884]:active{background-color:var(--color-background-dark)}button.is-active[data-v-3ea77884],button[data-v-3ea77884]:hover,button[data-v-3ea77884]:focus{opacity:1}button.icon-undo[data-v-3ea77884],button.icon-redo[data-v-3ea77884]{opacity:.4}\n","",{version:3,sources:["webpack://./src/views/DirectEditing.vue"],names:[],mappings:"AAgIA,sBACC,cAAe,CACf,gCAGA,UAAW,CACX,WAAY,CACZ,cAAe,CACf,eAAgB,CAJjB,kDAOE,WAAY,CACZ,KAAM,CARR,gEAWE,YAAa,CACb,qBAID,UAAW,CACX,eAAgB,CAChB,WAAY,CACZ,6CAA8C,CAC9C,wBAGA,UAAW,CACX,WAAY,CACZ,QAAS,CACT,oBAAqB,CACrB,QAAS,CACT,4BAA6B,CAC7B,UAAW,CACX,4BAA6B,CAC7B,iCAAkC,CAClC,kBAAmB,CAVpB,2FAYE,6CAA8C,CAZhD,8FAiBE,SAAU,CAjBZ,oEAqBE,UAAW",sourcesContent:["\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nbody {\n\tposition: fixed;\n}\n\n#direct-editor {\n\twidth: 100%;\n\theight: 100%;\n\tposition: fixed;\n\toverflow: hidden;\n\n\t&::v-deep #editor-container {\n\t\theight: 100%;\n\t\ttop: 0;\n\t}\n\t&::v-deep #editor-wrapper div.ProseMirror {\n\t\tmargin-top: 0;\n\t}\n}\n\npre {\n\twidth: 100%;\n\tmax-width: 700px;\n\tmargin: auto;\n\tbackground-color: var(--color-background-dark);\n}\n\nbutton {\n\twidth: 44px;\n\theight: 44px;\n\tmargin: 0;\n\tbackground-size: 16px;\n\tborder: 0;\n\tbackground-color: transparent;\n\topacity: .5;\n\tcolor: var(--color-main-text);\n\tbackground-position: center center;\n\tvertical-align: top;\n\t&:hover, &:focus, &:active {\n\t\tbackground-color: var(--color-background-dark);\n\t}\n\t&.is-active,\n\t&:hover,\n\t&:focus {\n\t\topacity: 1;\n\t}\n\n\t&.icon-undo, &.icon-redo {\n\t\topacity: .4;\n\t}\n}\n"],sourceRoot:""}]),n.a=s},839:function(t,n,e){"use strict";e.r(n);var r=e(895),o=e(254);for(var i in o)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return o[t]}))}(i);e(896),e(897);var s=e(12),a=Object(s.a)(o.default,r.a,r.b,!1,null,null,null);n.default=a.exports},840:function(t,n,e){"use strict";var r=e(20),o=e.n(r),i=e(21),s=e.n(i),a=e(224),c=e.n(a),l=e(225),d=s()(o.a),u=c()(l.a);d.push([t.i,"#read-only-editor{overflow:scroll}#read-only-editor div.ProseMirror{margin-top:44px;height:100%;position:relative;word-wrap:break-word;white-space:pre-wrap;-webkit-font-variant-ligatures:none;font-variant-ligatures:none;padding:4px 8px 200px 14px;line-height:150%;font-size:14px;outline:none}#read-only-editor div.ProseMirror[contenteditable=true],#read-only-editor div.ProseMirror[contenteditable=false],#read-only-editor div.ProseMirror [contenteditable=true],#read-only-editor div.ProseMirror [contenteditable=false]{border:none !important;width:100%;background-color:transparent;color:var(--color-main-text);opacity:1;-webkit-user-select:text;user-select:text;font-size:14px}#read-only-editor div.ProseMirror .checkbox-item{display:flex;align-items:start;margin-left:-23px}#read-only-editor div.ProseMirror .checkbox-item input[type=checkbox]{display:none}#read-only-editor div.ProseMirror .checkbox-item:before{content:'';vertical-align:middle;margin:3px 6px 3px 2px;border:1px solid var(--color-text-maxcontrast);position:relative;display:block;border-radius:var(--border-radius);height:14px;width:14px;box-shadow:none !important;background-position:center;cursor:pointer}#read-only-editor div.ProseMirror .checkbox-item.checked:before{background-image:url("+u+');background-color:var(--color-primary-element);border-color:var(--color-primary-element)}#read-only-editor div.ProseMirror .checkbox-item label{display:block;flex-grow:1;max-width:calc(100% - 28px)}#read-only-editor div.ProseMirror>*:first-child{margin-top:10px}#read-only-editor div.ProseMirror a{color:var(--color-primary-element);text-decoration:underline;padding:.5em 0}#read-only-editor div.ProseMirror p{margin-bottom:1em;line-height:150%}#read-only-editor div.ProseMirror em{font-style:italic}#read-only-editor div.ProseMirror h1,#read-only-editor div.ProseMirror h2,#read-only-editor div.ProseMirror h3,#read-only-editor div.ProseMirror h4,#read-only-editor div.ProseMirror h5,#read-only-editor div.ProseMirror h6{font-weight:600;line-height:120%;margin-top:24px;margin-bottom:12px;color:var(--color-main-text)}#read-only-editor div.ProseMirror h1{font-size:36px;margin-top:48px}#read-only-editor div.ProseMirror h2{font-size:30px;margin-top:48px}#read-only-editor div.ProseMirror h3{font-size:24px}#read-only-editor div.ProseMirror h4{font-size:21px}#read-only-editor div.ProseMirror h5{font-size:17px}#read-only-editor div.ProseMirror h6{font-size:14px}#read-only-editor div.ProseMirror img{cursor:default;max-width:100%}#read-only-editor div.ProseMirror hr{padding:2px 0;border:none;margin:3em 0;width:100%}#read-only-editor div.ProseMirror hr:after{content:"";display:block;height:1px;background-color:var(--color-border-dark);line-height:2px}#read-only-editor div.ProseMirror pre{white-space:pre;overflow-x:auto;background-color:var(--color-background-dark);border-radius:var(--border-radius);padding:1em 1.3em;margin-bottom:1em}#read-only-editor div.ProseMirror p code{background-color:var(--color-background-dark);border-radius:var(--border-radius);padding:.1em .3em}#read-only-editor div.ProseMirror li{position:relative;padding-left:3px}#read-only-editor div.ProseMirror li p{margin-bottom:0.5em}#read-only-editor div.ProseMirror ul,#read-only-editor div.ProseMirror ol{padding-left:10px;margin-left:10px;margin-bottom:1em}#read-only-editor div.ProseMirror ul li{list-style-type:disc}#read-only-editor div.ProseMirror ul>li>ul>li{list-style-type:circle}#read-only-editor div.ProseMirror ul>li>ul>li ul li{list-style-type:square}#read-only-editor div.ProseMirror blockquote{padding-left:1em;border-left:4px solid var(--color-primary-element);color:var(--color-text-maxcontrast);margin-left:0;margin-right:0}#read-only-editor .ProseMirror-focused .ProseMirror-gapcursor{display:block}#read-only-editor .editor__content p.is-empty:first-child::before{content:attr(data-empty-text);float:left;color:var(--color-text-maxcontrast);pointer-events:none;height:0}.thumbnailContainer #read-only-editor{width:100%}.thumbnailContainer #read-only-editor .ProseMirror{height:auto;margin:0 0 0 0;padding:0}\n',"",{version:3,sources:["webpack://./src/components/ReadOnlyEditor.vue","webpack://./css/prosemirror.scss"],names:[],mappings:"AAgEA,kBAEC,eAAgB,CAFjB,kCC9DC,eAAgB,CAChB,WAAY,CACZ,iBAAkB,CAClB,oBAAqB,CACrB,oBAAqB,CACrB,mCAAoC,CACpC,2BAA4B,CAC5B,0BAA2B,CAC3B,gBAAiB,CACjB,cAAe,CACf,YAAa,CDoDd,oOC9CE,sBAAuB,CACvB,UAAW,CACX,4BAA6B,CAC7B,4BAA6B,CAC7B,SAAU,CACV,wBAAyB,CACzB,gBAAiB,CACjB,cAAe,CDuCjB,iDCnCE,YAAa,CACb,iBAAkB,CAElB,iBAAkB,CDgCpB,sEC7BG,YAAa,CD6BhB,wDC1BG,UAAW,CACX,qBAAsB,CACtB,sBAAuB,CACvB,8CAA+C,CAC/C,iBAAkB,CAClB,aAAc,CACd,kCAAmC,CACnC,WAAY,CACZ,UAAW,CACX,0BAA2B,CAC3B,0BAA2B,CAC3B,cAAe,CDelB,gECZG,wDAAoD,CACpD,6CAA8C,CAC9C,yCAA0C,CDU7C,uDCPG,aAAc,CACd,WAAY,CACZ,2BAA4B,CDK/B,gDCAE,eAAgB,CDAlB,oCCIE,kCAAmC,CACnC,yBAA0B,CAC1B,cAAe,CDNjB,oCCUE,iBAAkB,CAClB,gBAAiB,CDXnB,qCCeE,iBAAkB,CDfpB,8NCwBE,eAAgB,CAChB,gBAAiB,CACjB,eAAgB,CAChB,kBAAmB,CACnB,4BAA6B,CD5B/B,qCCgCE,cAAe,CACf,eAAgB,CDjClB,qCCqCE,cAAe,CACf,eAAgB,CDtClB,qCC0CE,cAAe,CD1CjB,qCC8CE,cAAe,CD9CjB,qCCkDE,cAAe,CDlDjB,qCCsDE,cAAe,CDtDjB,sCC0DE,cAAe,CACf,cAAe,CD3DjB,qCC+DE,aAAc,CACd,WAAY,CACZ,YAAa,CACb,UAAW,CDlEb,2CCsEE,UAAW,CACX,aAAc,CACd,UAAW,CACX,yCAA0C,CAC1C,eAAgB,CD1ElB,sCC8EE,eAAgB,CAChB,eAAgB,CAChB,6CAA8C,CAC9C,kCAAmC,CACnC,iBAAkB,CAClB,iBAAkB,CDnFpB,yCCuFE,6CAA8C,CAC9C,kCAAmC,CACnC,iBAAkB,CDzFpB,qCC6FE,iBAAkB,CAClB,gBAAiB,CD9FnB,uCCiGG,mBAAoB,CDjGvB,0ECsGE,iBAAkB,CAClB,gBAAiB,CACjB,iBAAkB,CDxGpB,wCC4GE,oBAAqB,CD5GvB,8CCiHE,sBAAuB,CDjHzB,oDCsHE,sBAAuB,CDtHzB,6CC0HE,gBAAiB,CACjB,kDAAmD,CACnD,mCAAoC,CACpC,aAAc,CACd,cAAe,CD9HjB,8DCoIC,aAAc,CDpIf,kECwIC,6BAA8B,CAC9B,UAAW,CACX,mCAAoC,CACpC,mBAAoB,CACpB,QAAS,CDvIV,sCACC,UAAW,CADZ,mDAIE,WAAY,CACZ,cAAe,CACf,SAAU",sourcesContent:["\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n#read-only-editor {\n\t@import './../../css/prosemirror';\n\toverflow: scroll;\n}\n\n.thumbnailContainer #read-only-editor  {\n\twidth: 100%;\n\n\t.ProseMirror {\n\t\theight: auto;\n\t\tmargin: 0 0 0 0;\n\t\tpadding: 0;\n\t}\n}\n\n","/* Document rendering styles */\ndiv.ProseMirror {\n\tmargin-top: 44px;\n\theight: 100%;\n\tposition: relative;\n\tword-wrap: break-word;\n\twhite-space: pre-wrap;\n\t-webkit-font-variant-ligatures: none;\n\tfont-variant-ligatures: none;\n\tpadding: 4px 8px 200px 14px;\n\tline-height: 150%;\n\tfont-size: 14px;\n\toutline: none;\n\n\t&[contenteditable=true],\n\t&[contenteditable=false],\n\t[contenteditable=true],\n\t[contenteditable=false] {\n\t\tborder: none !important;\n\t\twidth: 100%;\n\t\tbackground-color: transparent;\n\t\tcolor: var(--color-main-text);\n\t\topacity: 1;\n\t\t-webkit-user-select: text;\n\t\tuser-select: text;\n\t\tfont-size: 14px;\n\t}\n\n\t.checkbox-item {\n\t\tdisplay: flex;\n\t\talign-items: start;\n\t\t// Left-align with list item text\n\t\tmargin-left: -23px;\n\n\t\tinput[type=checkbox] {\n\t\t\tdisplay: none;\n\t\t}\n\t\t&:before {\n\t\t\tcontent: '';\n\t\t\tvertical-align: middle;\n\t\t\tmargin: 3px 6px 3px 2px;\n\t\t\tborder: 1px solid var(--color-text-maxcontrast);\n\t\t\tposition: relative;\n\t\t\tdisplay: block;\n\t\t\tborder-radius: var(--border-radius);\n\t\t\theight: 14px;\n\t\t\twidth: 14px;\n\t\t\tbox-shadow: none !important;\n\t\t\tbackground-position: center;\n\t\t\tcursor: pointer;\n\t\t}\n\t\t&.checked:before {\n\t\t\tbackground-image: url('../../img/checkbox-mark.svg');\n\t\t\tbackground-color: var(--color-primary-element);\n\t\t\tborder-color: var(--color-primary-element);\n\t\t}\n\t\tlabel {\n\t\t\tdisplay: block;\n\t\t\tflex-grow: 1;\n\t\t\tmax-width: calc(100% - 28px);\n\t\t}\n\t}\n\n\t> *:first-child {\n\t\tmargin-top: 10px;\n\t}\n\n\ta {\n\t\tcolor: var(--color-primary-element);\n\t\ttext-decoration: underline;\n\t\tpadding: .5em 0;\n\t}\n\n\tp {\n\t\tmargin-bottom: 1em;\n\t\tline-height: 150%;\n\t}\n\n\tem {\n\t\tfont-style: italic;\n\t}\n\n\th1,\n\th2,\n\th3,\n\th4,\n\th5,\n\th6 {\n\t\tfont-weight: 600;\n\t\tline-height: 120%;\n\t\tmargin-top: 24px;\n\t\tmargin-bottom: 12px;\n\t\tcolor: var(--color-main-text);\n\t}\n\n\th1 {\n\t\tfont-size: 36px;\n\t\tmargin-top: 48px;\n\t}\n\n\th2 {\n\t\tfont-size: 30px;\n\t\tmargin-top: 48px;\n\t}\n\n\th3 {\n\t\tfont-size: 24px;\n\t}\n\n\th4 {\n\t\tfont-size: 21px;\n\t}\n\n\th5 {\n\t\tfont-size: 17px;\n\t}\n\n\th6 {\n\t\tfont-size: 14px;\n\t}\n\n\timg {\n\t\tcursor: default;\n\t\tmax-width: 100%;\n\t}\n\n\thr {\n\t\tpadding: 2px 0;\n\t\tborder: none;\n\t\tmargin: 3em 0;\n\t\twidth: 100%;\n\t}\n\n\thr:after {\n\t\tcontent: \"\";\n\t\tdisplay: block;\n\t\theight: 1px;\n\t\tbackground-color: var(--color-border-dark);\n\t\tline-height: 2px;\n\t}\n\n\tpre {\n\t\twhite-space: pre;\n\t\toverflow-x: auto;\n\t\tbackground-color: var(--color-background-dark);\n\t\tborder-radius: var(--border-radius);\n\t\tpadding: 1em 1.3em;\n\t\tmargin-bottom: 1em;\n\t}\n\n\tp code {\n\t\tbackground-color: var(--color-background-dark);\n\t\tborder-radius: var(--border-radius);\n\t\tpadding: .1em .3em;\n\t}\n\n\tli {\n\t\tposition: relative;\n\t\tpadding-left: 3px;\n\n\t\tp {\n\t\t\tmargin-bottom: 0.5em;\n\t\t}\n\t}\n\n\tul, ol {\n\t\tpadding-left: 10px;\n\t\tmargin-left: 10px;\n\t\tmargin-bottom: 1em;\n\t}\n\n\tul li {\n\t\tlist-style-type: disc;\n\t}\n\n\t// Second-level list entries\n\tul > li > ul > li {\n\t\tlist-style-type: circle;\n\t}\n\n\t// Third-level and further down list entries\n\tul > li > ul > li ul li {\n\t\tlist-style-type: square;\n\t}\n\n\tblockquote {\n\t\tpadding-left: 1em;\n\t\tborder-left: 4px solid var(--color-primary-element);\n\t\tcolor: var(--color-text-maxcontrast);\n\t\tmargin-left: 0;\n\t\tmargin-right: 0;\n\t}\n\n}\n\n.ProseMirror-focused .ProseMirror-gapcursor {\n\tdisplay: block;\n}\n\n.editor__content p.is-empty:first-child::before {\n\tcontent: attr(data-empty-text);\n\tfloat: left;\n\tcolor: var(--color-text-maxcontrast);\n\tpointer-events: none;\n\theight: 0;\n}\n"],sourceRoot:""}]),n.a=d},841:function(t,n,e){"use strict";var r=e(20),o=e.n(r),i=e(21),s=e.n(i),a=e(224),c=e.n(a),l=e(225),d=s()(o.a),u=c()(l.a);d.push([t.i,"div.ProseMirror{margin-top:44px;height:100%;position:relative;word-wrap:break-word;white-space:pre-wrap;-webkit-font-variant-ligatures:none;font-variant-ligatures:none;padding:4px 8px 200px 14px;line-height:150%;font-size:14px;outline:none}div.ProseMirror[contenteditable=true],div.ProseMirror[contenteditable=false],div.ProseMirror [contenteditable=true],div.ProseMirror [contenteditable=false]{border:none !important;width:100%;background-color:transparent;color:var(--color-main-text);opacity:1;-webkit-user-select:text;user-select:text;font-size:14px}div.ProseMirror .checkbox-item{display:flex;align-items:start;margin-left:-23px}div.ProseMirror .checkbox-item input[type=checkbox]{display:none}div.ProseMirror .checkbox-item:before{content:'';vertical-align:middle;margin:3px 6px 3px 2px;border:1px solid var(--color-text-maxcontrast);position:relative;display:block;border-radius:var(--border-radius);height:14px;width:14px;box-shadow:none !important;background-position:center;cursor:pointer}div.ProseMirror .checkbox-item.checked:before{background-image:url("+u+');background-color:var(--color-primary-element);border-color:var(--color-primary-element)}div.ProseMirror .checkbox-item label{display:block;flex-grow:1;max-width:calc(100% - 28px)}div.ProseMirror>*:first-child{margin-top:10px}div.ProseMirror a{color:var(--color-primary-element);text-decoration:underline;padding:.5em 0}div.ProseMirror p{margin-bottom:1em;line-height:150%}div.ProseMirror em{font-style:italic}div.ProseMirror h1,div.ProseMirror h2,div.ProseMirror h3,div.ProseMirror h4,div.ProseMirror h5,div.ProseMirror h6{font-weight:600;line-height:120%;margin-top:24px;margin-bottom:12px;color:var(--color-main-text)}div.ProseMirror h1{font-size:36px;margin-top:48px}div.ProseMirror h2{font-size:30px;margin-top:48px}div.ProseMirror h3{font-size:24px}div.ProseMirror h4{font-size:21px}div.ProseMirror h5{font-size:17px}div.ProseMirror h6{font-size:14px}div.ProseMirror img{cursor:default;max-width:100%}div.ProseMirror hr{padding:2px 0;border:none;margin:3em 0;width:100%}div.ProseMirror hr:after{content:"";display:block;height:1px;background-color:var(--color-border-dark);line-height:2px}div.ProseMirror pre{white-space:pre;overflow-x:auto;background-color:var(--color-background-dark);border-radius:var(--border-radius);padding:1em 1.3em;margin-bottom:1em}div.ProseMirror p code{background-color:var(--color-background-dark);border-radius:var(--border-radius);padding:.1em .3em}div.ProseMirror li{position:relative;padding-left:3px}div.ProseMirror li p{margin-bottom:0.5em}div.ProseMirror ul,div.ProseMirror ol{padding-left:10px;margin-left:10px;margin-bottom:1em}div.ProseMirror ul li{list-style-type:disc}div.ProseMirror ul>li>ul>li{list-style-type:circle}div.ProseMirror ul>li>ul>li ul li{list-style-type:square}div.ProseMirror blockquote{padding-left:1em;border-left:4px solid var(--color-primary-element);color:var(--color-text-maxcontrast);margin-left:0;margin-right:0}.ProseMirror-focused .ProseMirror-gapcursor{display:block}.editor__content p.is-empty:first-child::before{content:attr(data-empty-text);float:left;color:var(--color-text-maxcontrast);pointer-events:none;height:0}\n',"",{version:3,sources:["webpack://./css/prosemirror.scss"],names:[],mappings:"AACA,gBACC,eAAgB,CAChB,WAAY,CACZ,iBAAkB,CAClB,oBAAqB,CACrB,oBAAqB,CACrB,mCAAoC,CACpC,2BAA4B,CAC5B,0BAA2B,CAC3B,gBAAiB,CACjB,cAAe,CACf,YAAa,CAXd,4JAiBE,sBAAuB,CACvB,UAAW,CACX,4BAA6B,CAC7B,4BAA6B,CAC7B,SAAU,CACV,wBAAyB,CACzB,gBAAiB,CACjB,cAAe,CAxBjB,+BA4BE,YAAa,CACb,iBAAkB,CAElB,iBAAkB,CA/BpB,oDAkCG,YAAa,CAlChB,sCAqCG,UAAW,CACX,qBAAsB,CACtB,sBAAuB,CACvB,8CAA+C,CAC/C,iBAAkB,CAClB,aAAc,CACd,kCAAmC,CACnC,WAAY,CACZ,UAAW,CACX,0BAA2B,CAC3B,0BAA2B,CAC3B,cAAe,CAhDlB,8CAmDG,wDAAoD,CACpD,6CAA8C,CAC9C,yCAA0C,CArD7C,qCAwDG,aAAc,CACd,WAAY,CACZ,2BAA4B,CA1D/B,8BA+DE,eAAgB,CA/DlB,kBAmEE,kCAAmC,CACnC,yBAA0B,CAC1B,cAAe,CArEjB,kBAyEE,iBAAkB,CAClB,gBAAiB,CA1EnB,mBA8EE,iBAAkB,CA9EpB,kHAuFE,eAAgB,CAChB,gBAAiB,CACjB,eAAgB,CAChB,kBAAmB,CACnB,4BAA6B,CA3F/B,mBA+FE,cAAe,CACf,eAAgB,CAhGlB,mBAoGE,cAAe,CACf,eAAgB,CArGlB,mBAyGE,cAAe,CAzGjB,mBA6GE,cAAe,CA7GjB,mBAiHE,cAAe,CAjHjB,mBAqHE,cAAe,CArHjB,oBAyHE,cAAe,CACf,cAAe,CA1HjB,mBA8HE,aAAc,CACd,WAAY,CACZ,YAAa,CACb,UAAW,CAjIb,yBAqIE,UAAW,CACX,aAAc,CACd,UAAW,CACX,yCAA0C,CAC1C,eAAgB,CAzIlB,oBA6IE,eAAgB,CAChB,eAAgB,CAChB,6CAA8C,CAC9C,kCAAmC,CACnC,iBAAkB,CAClB,iBAAkB,CAlJpB,uBAsJE,6CAA8C,CAC9C,kCAAmC,CACnC,iBAAkB,CAxJpB,mBA4JE,iBAAkB,CAClB,gBAAiB,CA7JnB,qBAgKG,mBAAoB,CAhKvB,sCAqKE,iBAAkB,CAClB,gBAAiB,CACjB,iBAAkB,CAvKpB,sBA2KE,oBAAqB,CA3KvB,4BAgLE,sBAAuB,CAhLzB,kCAqLE,sBAAuB,CArLzB,2BAyLE,gBAAiB,CACjB,kDAAmD,CACnD,mCAAoC,CACpC,aAAc,CACd,cAAe,CACf,4CAKD,aAAc,CACd,gDAGA,6BAA8B,CAC9B,UAAW,CACX,mCAAoC,CACpC,mBAAoB,CACpB,QAAS",sourcesContent:["/* Document rendering styles */\ndiv.ProseMirror {\n\tmargin-top: 44px;\n\theight: 100%;\n\tposition: relative;\n\tword-wrap: break-word;\n\twhite-space: pre-wrap;\n\t-webkit-font-variant-ligatures: none;\n\tfont-variant-ligatures: none;\n\tpadding: 4px 8px 200px 14px;\n\tline-height: 150%;\n\tfont-size: 14px;\n\toutline: none;\n\n\t&[contenteditable=true],\n\t&[contenteditable=false],\n\t[contenteditable=true],\n\t[contenteditable=false] {\n\t\tborder: none !important;\n\t\twidth: 100%;\n\t\tbackground-color: transparent;\n\t\tcolor: var(--color-main-text);\n\t\topacity: 1;\n\t\t-webkit-user-select: text;\n\t\tuser-select: text;\n\t\tfont-size: 14px;\n\t}\n\n\t.checkbox-item {\n\t\tdisplay: flex;\n\t\talign-items: start;\n\t\t// Left-align with list item text\n\t\tmargin-left: -23px;\n\n\t\tinput[type=checkbox] {\n\t\t\tdisplay: none;\n\t\t}\n\t\t&:before {\n\t\t\tcontent: '';\n\t\t\tvertical-align: middle;\n\t\t\tmargin: 3px 6px 3px 2px;\n\t\t\tborder: 1px solid var(--color-text-maxcontrast);\n\t\t\tposition: relative;\n\t\t\tdisplay: block;\n\t\t\tborder-radius: var(--border-radius);\n\t\t\theight: 14px;\n\t\t\twidth: 14px;\n\t\t\tbox-shadow: none !important;\n\t\t\tbackground-position: center;\n\t\t\tcursor: pointer;\n\t\t}\n\t\t&.checked:before {\n\t\t\tbackground-image: url('../../img/checkbox-mark.svg');\n\t\t\tbackground-color: var(--color-primary-element);\n\t\t\tborder-color: var(--color-primary-element);\n\t\t}\n\t\tlabel {\n\t\t\tdisplay: block;\n\t\t\tflex-grow: 1;\n\t\t\tmax-width: calc(100% - 28px);\n\t\t}\n\t}\n\n\t> *:first-child {\n\t\tmargin-top: 10px;\n\t}\n\n\ta {\n\t\tcolor: var(--color-primary-element);\n\t\ttext-decoration: underline;\n\t\tpadding: .5em 0;\n\t}\n\n\tp {\n\t\tmargin-bottom: 1em;\n\t\tline-height: 150%;\n\t}\n\n\tem {\n\t\tfont-style: italic;\n\t}\n\n\th1,\n\th2,\n\th3,\n\th4,\n\th5,\n\th6 {\n\t\tfont-weight: 600;\n\t\tline-height: 120%;\n\t\tmargin-top: 24px;\n\t\tmargin-bottom: 12px;\n\t\tcolor: var(--color-main-text);\n\t}\n\n\th1 {\n\t\tfont-size: 36px;\n\t\tmargin-top: 48px;\n\t}\n\n\th2 {\n\t\tfont-size: 30px;\n\t\tmargin-top: 48px;\n\t}\n\n\th3 {\n\t\tfont-size: 24px;\n\t}\n\n\th4 {\n\t\tfont-size: 21px;\n\t}\n\n\th5 {\n\t\tfont-size: 17px;\n\t}\n\n\th6 {\n\t\tfont-size: 14px;\n\t}\n\n\timg {\n\t\tcursor: default;\n\t\tmax-width: 100%;\n\t}\n\n\thr {\n\t\tpadding: 2px 0;\n\t\tborder: none;\n\t\tmargin: 3em 0;\n\t\twidth: 100%;\n\t}\n\n\thr:after {\n\t\tcontent: \"\";\n\t\tdisplay: block;\n\t\theight: 1px;\n\t\tbackground-color: var(--color-border-dark);\n\t\tline-height: 2px;\n\t}\n\n\tpre {\n\t\twhite-space: pre;\n\t\toverflow-x: auto;\n\t\tbackground-color: var(--color-background-dark);\n\t\tborder-radius: var(--border-radius);\n\t\tpadding: 1em 1.3em;\n\t\tmargin-bottom: 1em;\n\t}\n\n\tp code {\n\t\tbackground-color: var(--color-background-dark);\n\t\tborder-radius: var(--border-radius);\n\t\tpadding: .1em .3em;\n\t}\n\n\tli {\n\t\tposition: relative;\n\t\tpadding-left: 3px;\n\n\t\tp {\n\t\t\tmargin-bottom: 0.5em;\n\t\t}\n\t}\n\n\tul, ol {\n\t\tpadding-left: 10px;\n\t\tmargin-left: 10px;\n\t\tmargin-bottom: 1em;\n\t}\n\n\tul li {\n\t\tlist-style-type: disc;\n\t}\n\n\t// Second-level list entries\n\tul > li > ul > li {\n\t\tlist-style-type: circle;\n\t}\n\n\t// Third-level and further down list entries\n\tul > li > ul > li ul li {\n\t\tlist-style-type: square;\n\t}\n\n\tblockquote {\n\t\tpadding-left: 1em;\n\t\tborder-left: 4px solid var(--color-primary-element);\n\t\tcolor: var(--color-text-maxcontrast);\n\t\tmargin-left: 0;\n\t\tmargin-right: 0;\n\t}\n\n}\n\n.ProseMirror-focused .ProseMirror-gapcursor {\n\tdisplay: block;\n}\n\n.editor__content p.is-empty:first-child::before {\n\tcontent: attr(data-empty-text);\n\tfloat: left;\n\tcolor: var(--color-text-maxcontrast);\n\tpointer-events: none;\n\theight: 0;\n}\n"],sourceRoot:""}]),n.a=d},842:function(t,n,e){"use strict";e.r(n);var r=e(898),o=e(256);for(var i in o)["default"].indexOf(i)<0&&function(t){e.d(n,t,(function(){return o[t]}))}(i);e(899);var s=e(12),a=Object(s.a)(o.default,r.a,r.b,!1,null,"7fd0186f",null);n.default=a.exports},843:function(t,n,e){"use strict";var r=e(20),o=e.n(r),i=e(21),s=e.n(i)()(o.a);s.push([t.i,"#resolve-conflicts[data-v-7fd0186f]{display:flex;position:fixed;z-index:10000;bottom:0;max-width:900px;width:100vw;margin:auto;padding:20px 0}#resolve-conflicts button[data-v-7fd0186f]{margin:auto;box-shadow:0 0 10px var(--color-box-shadow)}\n","",{version:3,sources:["webpack://./src/components/CollisionResolveDialog.vue"],names:[],mappings:"AAwCA,oCACC,YAAa,CACb,cAAe,CACf,aAAc,CACd,QAAS,CACT,eAAgB,CAChB,WAAY,CACZ,WAAY,CACZ,cAAe,CARhB,2CAWE,WAAY,CACZ,2CAA4C",sourcesContent:["\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n#resolve-conflicts {\n\tdisplay: flex;\n\tposition: fixed;\n\tz-index: 10000;\n\tbottom: 0;\n\tmax-width: 900px;\n\twidth: 100vw;\n\tmargin: auto;\n\tpadding: 20px 0;\n\n\tbutton {\n\t\tmargin: auto;\n\t\tbox-shadow: 0 0 10px var(--color-box-shadow);\n\t}\n}\n"],sourceRoot:""}]),n.a=s},885:function(t,n,e){"use strict";e.d(n,"a",(function(){return r})),e.d(n,"b",(function(){return o}));var r=function(){var t=this,n=t.$createElement,e=t._self._c||n;return e("div",{class:{"icon-loading":t.saving},attrs:{id:"direct-editor"}},[e("EditorWrapper",{ref:"editor",attrs:{"initial-session":t.initialSession,active:!0,mime:t.initial.mimetype,"is-direct-editing":!0},on:{ready:t.loaded},scopedSlots:t._u([{key:"header",fn:function(){return[e("button",{staticClass:"icon-share",on:{click:t.share}}),t._v(" "),e("button",{staticClass:"icon-close",on:{click:t.close}})]},proxy:!0}])})],1)},o=[]},886:function(t,n,e){"use strict";e.d(n,"a",(function(){return r})),e.d(n,"b",(function(){return o}));var r=function(){var t=this,n=t.$createElement,e=t._self._c||n;return e("div",{attrs:{id:"editor-container"}},[t.currentSession&&t.active?e("div",{staticClass:"document-status"},[t.idle?e("p",{staticClass:"msg"},[t._v("\n\t\t\t"+t._s(t.t("text","Document idle for {timeout} minutes, click to continue editing",{timeout:t.IDLE_TIMEOUT}))+" "),e("a",{staticClass:"button primary",on:{click:t.reconnect}},[t._v(t._s(t.t("text","Reconnect")))])]):t.hasSyncCollission?e("p",{staticClass:"msg icon-error"},[t._v("\n\t\t\t"+t._s(t.t("text","The document has been changed outside of the editor. The changes cannot be applied."))+"\n\t\t")]):t.hasConnectionIssue?e("p",{staticClass:"msg"},[t._v("\n\t\t\t"+t._s(t.t("text","File could not be loaded. Please check your internet connection."))+" "),e("a",{staticClass:"button primary",on:{click:t.reconnect}},[t._v(t._s(t.t("text","Reconnect")))])]):t._e()]):t._e(),t._v(" "),t.currentSession&&t.active?e("div",{class:{"has-conflicts":t.hasSyncCollission,"icon-loading":!t.initialLoading&&!t.hasConnectionIssue,richEditor:t.isRichEditor,"show-color-annotations":t.showAuthorAnnotations},attrs:{id:"editor-wrapper"}},[e("div",{attrs:{id:"editor"}},[t.syncError||t.readOnly?t._e():e("MenuBar",{ref:"menubar",attrs:{editor:t.tiptap,"file-path":t.relativePath,"is-rich-editor":t.isRichEditor,"is-public":t.isPublic,autohide:t.autohide}},[t.currentSession&&t.active?e("div",{attrs:{id:"editor-session-list"}},[e("div",{directives:[{name:"tooltip",rawName:"v-tooltip",value:t.lastSavedStatusTooltip,expression:"lastSavedStatusTooltip"}],staticClass:"save-status",class:t.lastSavedStatusClass},[t._v("\n\t\t\t\t\t\t"+t._s(t.lastSavedStatus)+"\n\t\t\t\t\t")]),t._v(" "),e("SessionList",{attrs:{sessions:t.filteredSessions}},[t.isPublic&&t.currentSession.guestName?e("GuestNameDialog",{attrs:{"sync-service":t.syncService}}):t._e()],1)],1):t._e(),t._v(" "),t._t("header")],2),t._v(" "),e("div",[!t.readOnly&&t.isRichEditor?e("MenuBubble",{attrs:{editor:t.tiptap,"file-path":t.relativePath}}):t._e(),t._v(" "),e("EditorContent",{directives:[{name:"show",rawName:"v-show",value:t.initialLoading,expression:"initialLoading"}],staticClass:"editor__content",attrs:{editor:t.tiptap}})],1)],1),t._v(" "),t.hasSyncCollission?e("ReadOnlyEditor",{attrs:{content:t.syncError.data.outsideChange,"is-rich-editor":t.isRichEditor}}):t._e()],1):t._e(),t._v(" "),t.hasSyncCollission&&!t.readOnly?e("CollisionResolveDialog",{on:{resolveUseThisVersion:t.resolveUseThisVersion,resolveUseServerVersion:t.resolveUseServerVersion}}):t._e()],1)},o=[]},887:function(t,n,e){"use strict";var r=e(19),o=e.n(r),i=e(818),s={insert:"head",singleton:!1};o()(i.a,s),i.a.locals},888:function(t,n,e){"use strict";var r=e(19),o=e.n(r),i=e(819),s={insert:"head",singleton:!1};o()(i.a,s),i.a.locals},889:function(t,n,e){"use strict";var r=e(19),o=e.n(r),i=e(820),s={insert:"head",singleton:!1};o()(i.a,s),i.a.locals},895:function(t,n,e){"use strict";e.d(n,"a",(function(){return r})),e.d(n,"b",(function(){return o}));var r=function(){var t=this.$createElement,n=this._self._c||t;return this.editor?n("EditorContent",{attrs:{id:"read-only-editor",editor:this.editor}}):this._e()},o=[]},896:function(t,n,e){"use strict";var r=e(19),o=e.n(r),i=e(840),s={insert:"head",singleton:!1};o()(i.a,s),i.a.locals},897:function(t,n,e){"use strict";var r=e(19),o=e.n(r),i=e(841),s={insert:"head",singleton:!1};o()(i.a,s),i.a.locals},898:function(t,n,e){"use strict";e.d(n,"a",(function(){return r})),e.d(n,"b",(function(){return o}));var r=function(){var t=this,n=t.$createElement,e=t._self._c||n;return e("div",{staticClass:"collision-resolve-dialog",attrs:{id:"resolve-conflicts"}},[e("button",{on:{click:function(n){return t.$emit("resolveUseThisVersion")}}},[t._v("\n\t\t"+t._s(t.t("text","Use current version"))+"\n\t")]),t._v(" "),e("button",{on:{click:function(n){return t.$emit("resolveUseServerVersion")}}},[t._v("\n\t\t"+t._s(t.t("text","Use the saved version"))+"\n\t")])])},o=[]},899:function(t,n,e){"use strict";var r=e(19),o=e.n(r),i=e(843),s={insert:"head",singleton:!1};o()(i.a,s),i.a.locals},904:function(t,n,e){"use strict";e.d(n,"a",(function(){return r})),e.d(n,"b",(function(){return o}));var r=function(){var t=this,n=t.$createElement,e=t._self._c||n;return e("div",{staticClass:"image",class:{"icon-loading":!t.loaded},attrs:{"data-src":t.src}},[t.imageLoaded&&t.isSupportedImage?e("div",{staticClass:"image__view"},[e("transition",{attrs:{name:"fade"}},[e("img",{directives:[{name:"show",rawName:"v-show",value:t.loaded,expression:"loaded"}],staticClass:"image__main",attrs:{src:t.imageUrl},on:{load:t.onLoaded}})]),t._v(" "),e("transition",{attrs:{name:"fade"}},[e("div",{directives:[{name:"show",rawName:"v-show",value:t.loaded,expression:"loaded"}],staticClass:"image__caption"},[e("input",{ref:"altInput",attrs:{type:"text"},domProps:{value:t.alt},on:{keyup:function(n){return!n.type.indexOf("key")&&t._k(n.keyCode,"enter",13,n.key,"Enter")?null:t.updateAlt()}}})])])],1):e("div",{staticClass:"image__placeholder"},[e("transition",{attrs:{name:"fade"}},[e("div",{directives:[{name:"show",rawName:"v-show",value:t.loaded,expression:"loaded"}],staticClass:"image__main"},[e("a",{attrs:{href:t.internalLinkOrImage,target:"_blank"}},[e("div",{staticClass:"icon-image",style:t.mimeIcon}),t._v(" "),t.isSupportedImage?t._e():e("p",[t._v(t._s(t.alt))])])])]),e("transition",{attrs:{name:"fade"}},[e("div",{directives:[{name:"show",rawName:"v-show",value:t.loaded,expression:"loaded"}],staticClass:"image__caption"},[e("input",{ref:"altInput",attrs:{type:"text"},domProps:{value:t.alt},on:{keyup:function(n){return!n.type.indexOf("key")&&t._k(n.keyCode,"enter",13,n.key,"Enter")?null:t.updateAlt()}}})])])],1)])},o=[]},905:function(t,n,e){"use strict";var r=e(19),o=e.n(r),i=e(654),s={insert:"head",singleton:!1};o()(i.a,s),i.a.locals}}]);
//# sourceMappingURL=editor.js.map?v=4b349a5cf139b2af34bb